@@ -533,8 +533,8 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Reset" : "Reafitar",
     "Room {roomNumber}" : "Sala {roomNumber}",
-    "Back" : "Atrás",
     "Cancel" : "Encaboxar",
+    "Back" : "Atrás",
     "Now" : "Agora",
     "Loading …" : "Cargando…",
     "From" : "De",
@@ -547,6 +547,7 @@ OC.L10N.register(
     "Raise hand" : "Alzar la mano",
     "Lower hand" : "Baxar la mano",
     "This conversation is read-only" : "Esta conversación ye namás de llectura",
+    "Reload" : "Volver cargar",
     "{nickName} raised their hand." : "«{nickName}» alzo la mano",
     "A participant raised their hand." : "Un participante alzó la mano.",
     "Previous page of videos" : "Páxina de vídeos anterior",
@@ -595,13 +596,13 @@ OC.L10N.register(
     "Matterbridge" : "Matterbridge",
     "Bots" : "Robós",
     "Danger zone" : "Zona de peligru",
-    "Error while deleting conversation" : "Hebo un error mentanto se desaniciaba la conversación",
-    "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
-    "Be careful, these actions cannot be undone." : "Ten curiáu, estes aiciones nun se puen desfacer.",
     "Leave conversation" : "Colar de la conversación",
     "Delete conversation" : "Desaniciar la conversación",
-    "Delete chat messages" : "Desaniciar los mensaxes de la charra",
+    "Error while deleting conversation" : "Hebo un error mentanto se desaniciaba la conversación",
     "Delete all chat messages" : "Desaniciar los mensaxes de toles charres",
+    "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
+    "Be careful, these actions cannot be undone." : "Ten curiáu, estes aiciones nun se puen desfacer.",
+    "Delete chat messages" : "Desaniciar los mensaxes de la charra",
     "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
     "_%n day_::_%n days_" : ["%n día","%n díes"],
     "_%n week_::_%n weeks_" : ["%n selmana","%n selmanes"],
@@ -658,7 +659,6 @@ OC.L10N.register(
     "Conversation list" : "Llista de conversaciones",
     "Unread messages" : "Mensaxes ensin lleer",
     "New personal note" : "Nota personal nueva",
-    "Talk settings" : "Configuración de Talk",
     "Users" : "Usuarios",
     "Groups" : "Grupos",
     "Teams" : "Equipos",
@@ -688,15 +688,15 @@ OC.L10N.register(
     "Files" : "Ficheros",
     "(edited)" : "(editóse)",
     "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
-    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
-    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
-    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
+    "24 hours" : "24 hores",
+    "7 days" : "7 díes",
     "Message text copied to clipboard" : "El testu del mensaxe copióse nel cartafueyu",
     "Message text could not be copied" : "El testu del mensaxe nun se pudo copiar",
     "A reminder was successfully removed" : "El recordatoriu quitóse correutamente",
     "Error occurred when removing a reminder" : "Prodúxose un error al quitar un recordatoriu",
     "Error occurred when creating a reminder" : "Prodúxose un error al crear un recordatoriu",
     "Reply" : "Responder",
+    "More actions" : "Más aiciones",
     "Set reminder" : "Configurar un recordatoriu",
     "Reply privately" : "Responder per privao",
     "Edit message" : "Editar el mensaxe",
@@ -712,6 +712,7 @@ OC.L10N.register(
     "Translate message" : "Traducir el mensaxe",
     "Translating" : "Traduciendo",
     "Copy translated text" : "Copiar el testu traducíu",
+    "Send now" : "Unviar agora",
     "Message sent" : "Unvióse'l mensaxe",
     "Deleting message" : "Desaniciando'l mensaxe",
     "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
@@ -720,9 +721,6 @@ OC.L10N.register(
     "Not enough free space to upload file" : "Nun hai abondu espaciu llibre pa xubir el ficheru",
     "You are not allowed to share files" : "Nun tienes permisu pa compartir ficheros",
     "You cannot send messages to this conversation at the moment" : "Pel momentu, nun pues unviar mensaxes a esta conversación",
-    "Code block copied to clipboard" : "El bloque de códigu copióse nel cartafueyu",
-    "Code block could not be copied" : "Nun se pudo copiar el bloque de códigu",
-    "Copy code block" : "Copiar el bloque de códigu",
     "Open poll • You voted already" : "Encuesta abierta • Yá votesti",
     "Open poll • Click to vote" : "Encuesta abierta • Calca pa votar",
     "Poll • Ended" : "Encuesta • Finó",
@@ -732,6 +730,7 @@ OC.L10N.register(
     "Show all reactions" : "Amosar toles reaiciones",
     "Add more reactions" : "Amestar más reaiciones",
     "No messages" : "Nun hai nengún mensaxe",
+    "Unpin" : "Lliberar",
     "Add participants" : "Amestar participantes",
     "Conversation visibility" : "Visibilidá de la conversación",
     "This conversation has been locked" : "Bloquióse esta conversación",
@@ -740,6 +739,7 @@ OC.L10N.register(
     "The message could not be edited" : "Nun se pudo editar el mensaxe",
     "File upload is not available in this conversation" : "La xuba de ficheros nun ta disponible nesta conversación",
     "Add emoji" : "Amestar un fustaxe",
+    "Send later" : "Unviar dempués",
     "Smart picker" : "Selector intelixente",
     "New file" : "Ficheru nuevu",
     "Blank" : "Baleru",
@@ -822,18 +822,11 @@ OC.L10N.register(
     "Phone numbers" : "Númberos de teléfonu",
     "Display name: {name}" : "Nome visible: {name}",
     "Save name" : "Guardar el nome",
-    "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
-    "Sounds setting saved" : "Guardóse la configuración de los soníos",
     "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
-    "Browse …" : "Restolar…",
-    "Appearance" : "Aspeutu",
+    "Notification settings" : "Configuración de los avisos",
+    "Default language" : "Llingua predeterminada",
     "Privacy" : "Privacidá",
-    "Sounds" : "Soníos",
-    "Performance" : "Rindimientu",
-    "Keyboard shortcuts" : "Atayos del tecláu",
     "Search" : "Buscar",
-    "Space bar" : "Barra d'espaciu",
-    "More actions" : "Más aiciones",
     "Start call" : "Aniciar la llamada",
     "End call" : "Finar la llamada",
     "Stop recording" : "Parar la grabación",
@@ -933,6 +926,9 @@ OC.L10N.register(
     "_In %n hour_::_In %n hours_" : ["En %n hora","En %n hores"],
     "_%n minute _::_%n minutes_" : ["%n minutu","%n minutos"],
     "_In %n minute_::_In %n minutes_" : ["En %n minutu","En %n minutos"],
+    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
+    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
+    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
     "Conversation link copied to clipboard" : "L'enllaz de la conversación copióse nel cartafueyu",
     "The link could not be copied" : "Nun se pudo copiar l'enllaz",
     "Please reload the page." : "Volvi cargar la páxina.",
@@ -953,11 +949,20 @@ OC.L10N.register(
     "Reports" : "Informes",
     "Call summary" : "Resume de llamaes",
     "You were invited to a conversation." : "Convidáronte a una conversación.",
+    "Talk settings" : "Configuración de Talk",
     "Media settings" : "Configuración multimedia",
     "Normal call" : "Llamada normal",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
     "A week ago" : "Hai una selmana",
-    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"]
+    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
+    "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
+    "Sounds setting saved" : "Guardóse la configuración de los soníos",
+    "Browse …" : "Restolar…",
+    "Appearance" : "Aspeutu",
+    "Sounds" : "Soníos",
+    "Performance" : "Rindimientu",
+    "Keyboard shortcuts" : "Atayos del tecláu",
+    "Space bar" : "Barra d'espaciu"
 },
 "nplurals=2; plural=(n != 1);");
