@@ -613,13 +613,14 @@ OC.L10N.register(
     "Create breakout rooms" : "Luo pienryhmätilat",
     "Reset" : "Palauta",
     "Delete breakout rooms" : "Poista pienryhmätilat",
-    "Current breakout rooms and settings will be lost" : "Nykyisen pienryhmätilat ja asetukset katoavat",
     "Room {roomNumber}" : "Huone {roomNumber}",
+    "Current breakout rooms and settings will be lost" : "Nykyisen pienryhmätilat ja asetukset katoavat",
+    "Cancel" : "Peruuta",
     "Unassigned participants" : "Osallistujat joita ei ole määritetty",
     "Back" : "Takaisin",
-    "Cancel" : "Peruuta",
     "Add participant \"{user}\"" : "Lisää osallistuja \"{user}\"",
     "Now" : "Nyt",
+    "Meeting" : "Kokous",
     "Loading …" : "Ladataan…",
     "From" : "Lähettäjä",
     "To" : "Vastaanottaja",
@@ -638,6 +639,7 @@ OC.L10N.register(
     "Speaker view" : "Puhujan näkymä",
     "Grid view" : "Ruudukkonäkymä",
     "This conversation is read-only" : "Keskustelu on \"vain luku\"-tilassa",
+    "Reload" : "Päivitä",
     "{nickName} raised their hand." : "{nickName} nosti kätensä.",
     "A participant raised their hand." : "Osallistuja nosti kätensä.",
     "Previous page of videos" : "Videoiden edellinen sivu",
@@ -707,6 +709,7 @@ OC.L10N.register(
     "Disable" : "Poista käytöstä",
     "Enable" : "Käytä",
     "Breakout rooms" : "Pienryhmätilat",
+    "Manage breakout rooms" : "Hallitse pienryhmätiloja",
     "Set up breakout rooms for this conversation" : "Määritä tämän keskustelun pienryhmätilat",
     "Please select a valid PNG or JPG file" : "Valitse kelvollinen PNG- tai JPG-tiedosto",
     "Choose your conversation picture" : "Valitse keskustelukuva",
@@ -729,7 +732,6 @@ OC.L10N.register(
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Osallistujat voivat liittyä puheluihin, mutta eivät voi ottaa ääntä tai videota käyttöön tai jakaa näyttönsä sisältöä, ennen kuin moderaattori on antanut siihen luvan.",
     "Advanced permissions" : "Edistyneet oikeudet",
     "Edit permissions" : "Muokkaa oikeuksia",
-    "Meeting" : "Kokous",
     "Conversation settings" : "Keskustelun asetukset",
     "Basic Info" : "Perustiedot",
     "Personal" : "Henkilökohtainen",
@@ -737,17 +739,17 @@ OC.L10N.register(
     "Matterbridge" : "Matterbridge",
     "Bots" : "Botit",
     "Danger zone" : "Vaaravyöhyke",
+    "Leave conversation" : "Poistu keskustelusta",
+    "Delete conversation" : "Poista keskustelu",
     "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
     "Error while deleting conversation" : "Virhe keskustelua poistaessa",
+    "Delete all chat messages" : "Poista kaikki keskustelun viestit",
     "Error while clearing chat history" : "Virhe keskusteluhistoriaa siivotessa",
     "Be careful, these actions cannot be undone." : "Ole varovainen, näitä toimintoja ei voi perua.",
-    "Leave conversation" : "Poistu keskustelusta",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kun olet kerran poistunut suljetusta keskustelusta, tarvitset kutsun liittyäksesi uudelleen siihen. Avoimeen keskusteluun on mahdollista liittyä milloin hyvänsä.",
-    "Delete conversation" : "Poista keskustelu",
     "Permanently delete this conversation." : "Poista tämä keskustelu pysyvästi.",
     "Delete chat messages" : "Poista keskustelun viestit",
     "Permanently delete all the messages in this conversation." : "Poista pysyvästi kaikki tämän keskustelun viestit.",
-    "Delete all chat messages" : "Poista kaikki keskustelun viestit",
     "_%n hour_::_%n hours_" : ["%n tunti","%n tuntia"],
     "_%n day_::_%n days_" : ["%n päivä","%n päivää"],
     "_%n week_::_%n weeks_" : ["%n viikko","%n viikkoa"],
@@ -833,7 +835,7 @@ OC.L10N.register(
     "Clear filters" : "Tyhjennä suodattimet",
     "New personal note" : "Uusi henkilökohtainen muistiinpano",
     "Clear filter" : "Tyhjennä suodatin",
-    "Talk settings" : "Talk-asetukset",
+    "App settings" : "Sovelluksen asetukset",
     "Users" : "Käyttäjät",
     "Groups" : "Ryhmät",
     "Teams" : "Tiimit",
@@ -886,19 +888,14 @@ OC.L10N.register(
     "(edited)" : "(muokattu)",
     "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
     "Cancel quote" : "Peruuta lainaus",
-    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
-    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
-    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
-    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
-    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
-    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
-    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
-    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
+    "24 hours" : "24 tuntia",
+    "7 days" : "7 päivää",
     "Clear reminder – {timeLocale}" : "Tyhjennä muistutus – {timeLocale}",
     "Message text copied to clipboard" : "Viestin teksti kopioitu leikepöydälle",
     "Message text could not be copied" : "Viestin tekstiä ei voitu kopioida",
     "Add a reaction to this message" : "Lisää reaktio tähän viestiin",
     "Reply" : "Vastaa",
+    "More actions" : "Lisää toimintoja",
     "Set reminder" : "Aseta muistutus",
     "Reply privately" : "Vastaa yksityisesti",
     "Edit message" : "Muokkaa viestiä",
@@ -925,6 +922,7 @@ OC.L10N.register(
     "Translate to" : "Kohdekieli",
     "Translating" : "Käännetään",
     "Copy translated text" : "Kopioi käännetty teksti",
+    "Send now" : "Lähetä nyt",
     "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
     "Message sent" : "Viesti lähetetty",
     "Deleting message" : "Poistetaan viestiä",
@@ -932,7 +930,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Viestiä ei voitu poistaa, koska se on liian vanha",
     "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
     "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
-    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
     "Your browser does not support playing audio files" : "Selaimesi ei tue äänitiedostojen toistamista",
     "Contact" : "Yhteystieto",
     "Remove {fileName}" : "Poista {fileName}",
@@ -942,17 +939,16 @@ OC.L10N.register(
     "Not enough free space to upload file" : "Ei riittävästi vapaata tilaa tiedoston lähettämiseksi",
     "You are not allowed to share files" : "Sinulla ei ole oikeutta jakaa tiedostoja",
     "You cannot send messages to this conversation at the moment" : "Et voi lähettää viestejä tähän keskusteluun tällä hetkellä",
-    "Code block copied to clipboard" : "Koodilohko kopioitu leikepöydälle",
-    "Code block could not be copied" : "Koodilohkoa ei voitu kopioida",
-    "Copy code block" : "Kopioi koodilohko",
     "Poll" : "Kysely",
     "See results" : "Näytä tulokset",
     "Reactions" : "Reaktiot",
     "No permission to post reactions in this conversation" : "Ei oikeutta lähettää reaktioita tähän keskusteluun",
     "Show all reactions" : "Näytä kaikki reaktiot",
     "Add more reactions" : "Lisää enemmän reaktioita",
+    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
     "No messages" : "Ei viestejä",
     "All messages have expired or have been deleted." : "Kaikki viestit ovat vanhentuneet tai ne on poistettu.",
+    "Unpin" : "Poista kiinnitys",
     "Cancel search" : "Peruuta haku",
     "Add a phone number" : "Lisää puhelinnumero",
     "All set, the conversation \"{conversationName}\" was created." : "Kaikki valmista, keskustelu \"{conversationName}\" luotu.",
@@ -968,12 +964,14 @@ OC.L10N.register(
     "Send without notification" : "Lähetä ilman ilmoitusta",
     "File to share" : "Jaettava tiedosto",
     "Add emoji" : "Lisää emoji",
+    "Send later" : "Lähetä myöhemmin",
     "Cancel editing" : "Peruuta muokkaus",
     "Share from {nextcloud}" : "Jaa lähteestä {nextcloud}",
     "Share from Files" : "Jaa tiedostoista",
     "Share files to the conversation" : "Jaa tiedostoja keskusteluun",
     "Upload from device" : "Lähetä laitteelta",
     "Create new poll" : "Luo uusi kysely",
+    "Smart picker" : "Älykäs valitsin",
     "Record voice message" : "Äänitä ääniviesti",
     "End recording and send" : "Lopeta äänitys ja lähetä",
     "Dismiss recording" : "Hylkää äänitallenne",
@@ -1023,7 +1021,6 @@ OC.L10N.register(
     "Assistance requested in {roomName}" : "Apua pyydetty pienryhmätilassa {roomName}",
     "The message was sent to \"{roomName}\"" : "Viesti lähetettiin huoneeseen \"{roomName}\"",
     "Send message to room" : "Lähetä viesti huoneeseen",
-    "Manage breakout rooms" : "Hallitse pienryhmätiloja",
     "Back to main room" : "Takaisin päähuoneeseen",
     "Back to your room" : "Takaisin omaan huoneeseen",
     "Message all rooms" : "Viesti kaikkiin huoneisiin",
@@ -1100,36 +1097,24 @@ OC.L10N.register(
     "Display name: {name}" : "Näyttönimi: {name}",
     "Edit display name" : "Muokkaa näyttönimeä",
     "Save name" : "Tallenna nimi",
-    "Choose the folder in which attachments should be saved." : "Valitse mihin kansioon liitteet tulee tallentaa.",
+    "Error while saving sounds setting" : "Virhe ääniasetuksia tallentaessa",
+    "Play sounds when participants join or leave a call" : "Toista ääni kun osallistuja liittyy tai poistuu puhelusta",
+    "Notification settings" : "Ilmoitusasetukset",
+    "Default language" : "Oletuskieli",
     "Select location for attachments" : "Valitse sijainti liitteille",
     "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
-    "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
-    "Failed to save sounds setting" : "Ääniasetusten tallentaminen epäonnistui",
-    "Sounds setting saved" : "Ääniasetukset tallennettu",
-    "Error while saving sounds setting" : "Virhe ääniasetuksia tallentaessa",
-    "Attachments folder" : "Liitteiden kansio",
-    "Browse …" : "Selaa…",
-    "Appearance" : "Ulkoasu",
     "Privacy" : "Yksityisyys",
-    "Share my read-status and show the read-status of others" : "Jaa lukukuittaukseni ja näytä muiden lukukuittaukset",
-    "Sounds" : "Äänet",
-    "Play sounds when participants join or leave a call" : "Toista ääni kun osallistuja liittyy tai poistuu puhelusta",
-    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Keskustelu- ja puheluilmoitusten ääniä voi muuttaa henkilökohtaisisten asetusten kautta.",
-    "Performance" : "Suorituskyky",
-    "Keyboard shortcuts" : "Pikanäppäimet",
-    "Speed up your Talk experience with these quick shortcuts." : "Nopeuta Talk-kokemusta näillä pikanäppäimillä.",
+    "Attachments folder" : "Liitteiden kansio",
+    "Toggle full screen" : "Koko näyttö päälle/pois",
+    "Search" : "Etsi",
     "Focus the chat input" : "Kohdista keskustelun syötteeseen",
     "Unfocus the chat input to use shortcuts" : "Poista kohdistus keskustelusta käyttääksesi pikanäppäimiä",
     "Edit your last message" : "Muokkaa viimeistä viestiäsi",
-    "Fullscreen the chat or call" : "Keskustelu tai puhelu koko näyttöön",
-    "Search" : "Etsi",
     "Shortcuts while in a call" : "Pikanäppäimet puhelun aikana",
     "Camera on and off" : "Kamera päälle tai pois päältä",
     "Microphone on and off" : "Mikrofoni päälle tai pois päältä",
-    "Space bar" : "Välilyönti",
-    "Push to talk or push to mute" : "Paina puhuaksesi tai mykistääksesi",
     "Raise or lower hand" : "Nosta tai laske käsi",
-    "More actions" : "Lisää toimintoja",
+    "Push to talk or push to mute" : "Paina puhuaksesi tai mykistääksesi",
     "Start call silently" : "Aloita puhelu hiljennettynä",
     "Start call" : "Aloita puhelu",
     "End call" : "Lopeta puhelu",
@@ -1161,7 +1146,6 @@ OC.L10N.register(
     "Mute others" : "Mykistä muut",
     "Start recording" : "Käynnistä tallennus",
     "Set up breakout rooms" : "Määritä pienryhmätilat",
-    "Toggle full screen" : "Koko näyttö päälle/pois",
     "Remove participant {name}" : "Poista osallistuja {name}",
     "Open dialpad" : "Avaa numeronäppäimistö",
     "Select a region" : "Valitse alue",
@@ -1265,6 +1249,10 @@ OC.L10N.register(
     "Failed to add reaction" : "Reaktion lisääminen epäonnistui",
     "Failed to remove reaction" : "Reaktion poistaminen epäonnistui",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ei tue täysin käyttämääsi selainta. Käytä uusinta versiota Mozilla Firefoxista, Microsoft Edgestä, Google Chromesta, Operasta tai Apple Safarista.",
+    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
+    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "Conversation link copied to clipboard" : "Keskustelulinkki kopioitu leikepöydälle",
     "The link could not be copied" : "Linkkiä ei voitu kopioida",
     "Please reload the page." : "Päivitä sivu.",
@@ -1298,6 +1286,7 @@ OC.L10N.register(
     "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
     "Join »%s«" : "Liity »%s«",
     "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
+    "Talk settings" : "Talk-asetukset",
     "Refresh devices list" : "Päivitä laitelista",
     "Media settings" : "Media-asetukset",
     "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
@@ -1305,11 +1294,29 @@ OC.L10N.register(
     "The conversation participants will not be notified about this call" : "Keskustelun osallistujille ei ilmoiteta tästä puhelusta",
     "Normal call" : "Normaali puhelu",
     "The conversation participants will be notified about this call" : "Keskustelun osallistujille ilmoitetaan tästä puhelusta",
+    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
+    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
+    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
+    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
     "A week ago" : "Viikko sitten",
     "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
+    "Choose the folder in which attachments should be saved." : "Valitse mihin kansioon liitteet tulee tallentaa.",
+    "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
+    "Failed to save sounds setting" : "Ääniasetusten tallentaminen epäonnistui",
+    "Sounds setting saved" : "Ääniasetukset tallennettu",
     "Choose devices" : "Valitse laitteet",
+    "Browse …" : "Selaa…",
+    "Appearance" : "Ulkoasu",
+    "Share my read-status and show the read-status of others" : "Jaa lukukuittaukseni ja näytä muiden lukukuittaukset",
+    "Sounds" : "Äänet",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Keskustelu- ja puheluilmoitusten ääniä voi muuttaa henkilökohtaisisten asetusten kautta.",
+    "Performance" : "Suorituskyky",
+    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Speed up your Talk experience with these quick shortcuts." : "Nopeuta Talk-kokemusta näillä pikanäppäimillä.",
+    "Fullscreen the chat or call" : "Keskustelu tai puhelu koko näyttöön",
+    "Space bar" : "Välilyönti",
     "Blur background" : "Sumenna tausta",
     "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
     "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
