@@ -22,8 +22,10 @@ OC.L10N.register(
     "{actor} created the conversation" : "{actor} membuat sebuah percakapan",
     "You created the conversation" : "Anda membuat sebuah percakapan",
     "Message deleted by author" : "Pesan dihapus oleh penyusun",
+    "Deleted user" : "Pengguna dihapus",
     "Administration" : "Administrasi",
     "System" : "Sistem",
+    "Talk to %s" : "Chat dengan %s",
     "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas tidak valid",
     "Invalid image" : "Gambar tidak valid",
@@ -31,12 +33,17 @@ OC.L10N.register(
     "Say hi to your friends and colleagues!" : "Katakan halo kepada teman dan kolega Anda!",
     "You were mentioned" : "Anda disebutkan",
     "Description" : "Deskrisi",
+    "Talk conversation for event" : "Percakapan Talk untuk acara",
     "Dismiss notification" : "Abaikan notifikasi",
     "Accept" : "Terima",
     "Decline" : "Tolak",
     "New message" : "Pesan baru",
     "Notification" : "Notifikasi",
+    "{user} in {call}" : "{user} di {call}",
+    "Open settings" : "Buka pengaturan",
     "error" : "galat",
+    "{user} in {conversation}" : "{user} di {conversation}",
+    "Avatar image is not square" : "Gambar avatar tidak berbentuk persegi",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Uni Emirat Arab",
     "Afghanistan" : "Afganistan",
@@ -64,6 +71,7 @@ OC.L10N.register(
     "Benin" : "Benin",
     "Saint Barthélemy" : "Saint Barthelemy",
     "Bermuda" : "Bermuda",
+    "Brunei Darussalam" : "Brunei Darussalam",
     "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius dan Saba",
     "Brazil" : "Brazil",
     "Bahamas" : "Bahamas",
@@ -77,6 +85,7 @@ OC.L10N.register(
     "Central African Republic" : "Republik Afrika Tengah",
     "Congo" : "Congo",
     "Switzerland" : "Swiss",
+    "Côte d'Ivoire" : "Pantai Gading",
     "Cook Islands" : "Pulau Cook",
     "Chile" : "Chile",
     "Cameroon" : "Cameroon",
@@ -88,22 +97,27 @@ OC.L10N.register(
     "Curaçao" : "Curaçao",
     "Christmas Island" : "Pulau Natal",
     "Cyprus" : "Cyprus",
+    "Czechia" : "Ceko",
     "Germany" : "Jerman",
     "Djibouti" : "Djibouti",
     "Denmark" : "Denmark",
+    "Dominica" : "Dominika",
     "Dominican Republic" : "Republik Dominika",
     "Algeria" : "Algeria",
     "Ecuador" : "Ekuador",
     "Estonia" : "Estonia",
     "Egypt" : "Mesir",
+    "Western Sahara" : "Sahara Barat",
     "Eritrea" : "Eritrea",
     "Spain" : "Spanyol",
     "Ethiopia" : "Ethiopia",
     "Finland" : "Finlandia",
     "Fiji" : "Fiji",
+    "Falkland Islands (Malvinas)" : "Kepulauan Falkland (Malvinas)",
     "Faroe Islands" : "Pulau Faroe",
     "France" : "Prancis",
     "Gabon" : "Gabon",
+    "United Kingdom of Great Britain and Northern Ireland" : "Britania Raya Britania Raya dan Irlandia Utara",
     "Grenada" : "Grenada",
     "Georgia" : "Georgia",
     "French Guiana" : "Guyana Prancis",
@@ -136,6 +150,7 @@ OC.L10N.register(
     "Iraq" : "Irak",
     "Iceland" : "Islandia",
     "Italy" : "Italia",
+    "Jersey" : "Jersey",
     "Jamaica" : "Jamaika",
     "Jordan" : "Jordan",
     "Japan" : "Jepang",
@@ -143,10 +158,12 @@ OC.L10N.register(
     "Kyrgyzstan" : "Kirgizstan",
     "Cambodia" : "Kambodia",
     "Kiribati" : "Kiribati",
+    "Comoros" : "Komoro",
     "Saint Kitts and Nevis" : "Saint Kitts dan Nevis",
     "Kuwait" : "Kuwait",
     "Cayman Islands" : "Kepulauan Cayman",
     "Kazakhstan" : "Kazakhstan",
+    "Lao People's Democratic Republic" : "Laos (Republik Demokratik Rakyat)",
     "Lebanon" : "Lebanon",
     "Saint Lucia" : "Saint Lucia",
     "Liechtenstein" : "Liechtenstein",
@@ -160,13 +177,16 @@ OC.L10N.register(
     "Morocco" : "Maroko",
     "Monaco" : "Monako",
     "Montenegro" : "Montenegro",
+    "Saint Martin (French part)" : "Saint Martin (bagian Prancis)",
     "Madagascar" : "Madagascar",
     "Marshall Islands" : "Kepulauan Marshall",
+    "North Macedonia" : "Makedonia Utara",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongolia",
     "Macao" : "Macao",
     "Northern Mariana Islands" : "Kepulauan Mariana Utara",
+    "Martinique" : "Martinik",
     "Mauritania" : "Mauritania",
     "Montserrat" : "Montserrat",
     "Malta" : "Malta",
@@ -199,6 +219,7 @@ OC.L10N.register(
     "Saint Pierre and Miquelon" : "Saint Pierre dan Miquelon",
     "Pitcairn" : "Pitcairn",
     "Puerto Rico" : "Puerto Rico",
+    "Palestine, State of" : "Palestina, Negara",
     "Portugal" : "Portugis",
     "Palau" : "Palau",
     "Paraguay" : "Paraguay",
@@ -206,6 +227,7 @@ OC.L10N.register(
     "Réunion" : "Réunion",
     "Romania" : "Romania",
     "Serbia" : "Serbia",
+    "Russian Federation" : "Federasi Rusia",
     "Rwanda" : "Rwanda",
     "Saudi Arabia" : "Arab Saudi",
     "Solomon Islands" : "Kepulauan Solomon",
@@ -225,8 +247,11 @@ OC.L10N.register(
     "South Sudan" : "Sudan Selatan",
     "Sao Tome and Principe" : "Sao Tome dan Principe",
     "El Salvador" : "El Salvador",
+    "Sint Maarten (Dutch part)" : "Sint Maarten (bagian Belanda)",
+    "Syrian Arab Republic" : "Republik Arab Suriah",
     "Turks and Caicos Islands" : "Kepulauan Turks dan Caicos",
     "Chad" : "Chad",
+    "French Southern Territories" : "Wilayah Selatan Prancis",
     "Togo" : "Togo",
     "Thailand" : "Thailand",
     "Tajikistan" : "Tajikistan",
@@ -238,13 +263,16 @@ OC.L10N.register(
     "Turkey" : "Turki",
     "Trinidad and Tobago" : "Trinidad dan Tobago",
     "Tuvalu" : "Tuvalu",
+    "Tanzania, United Republic of" : "Tanzania (Republik Bersatu)",
     "Ukraine" : "Ukraina",
     "Uganda" : "Uganda",
     "United States Minor Outlying Islands" : "Pulau Kecil Terluar Amerika Serikat",
+    "United States of America" : "Amerika Serikat",
     "Uruguay" : "Uruguay",
     "Uzbekistan" : "Uzbekistan",
     "Holy See" : "Holy See",
     "Saint Vincent and the Grenadines" : "Saint Vincent dan Grenadine",
+    "Viet Nam" : "Viet Nam",
     "Vanuatu" : "Vanuatu",
     "Wallis and Futuna" : "Wallis dan Futuna",
     "Samoa" : "Samoa",
@@ -259,20 +287,30 @@ OC.L10N.register(
     "Everyone" : "Semua orang",
     "Save changes" : "Simpan perubahan",
     "Saving …" : "Menyimpan ...",
+    "Saved!" : "Disimpan!",
     "Limit to groups" : "Batasi ke grup",
     "Enabled" : "Diaktifkan",
     "Disabled" : "Dinonaktifkan",
     "State" : "Kondisi",
     "Name" : "Nama",
+    "Beta" : "Beta",
+    "Permissions" : "Izin",
     "Off" : "Nonaktif",
+    "General settings" : "Pengaturan umum",
     "Enable encryption" : "Aktifkan enkripsi",
     "Pending" : "Tunggu",
     "Error" : "Kesalahan",
+    "Active" : "Aktif",
+    "Expired" : "Kedaluwarsa",
     "Never" : "Tidak pernah",
     "Language" : "Bahasa",
     "Country" : "Negara",
     "Status" : "Status",
     "Created at" : "Dibuat saat",
+    "Yes" : "Ya",
+    "No" : "Tidak",
+    "Shared secret" : "Rahasia bersama",
+    "{option1} and {option2}" : "{option1} dan {option2}",
     "Failed" : "Gagal",
     "OK" : "OK",
     "Federated user" : "Pengguna terfederasi",
@@ -283,6 +321,8 @@ OC.L10N.register(
     "Now" : "Sekarang",
     "Meeting" : "Rapat",
     "Loading …" : "Memuat …",
+    "From" : "Dari",
+    "To" : "Hingga",
     "Calendar" : "Kalender",
     "Attendees" : "Peserta",
     "Save" : "Simpan",
@@ -298,75 +338,140 @@ OC.L10N.register(
     "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
     "Favorite" : "Favorit",
     "Date:" : "Tanggal:",
+    "Note:" : "Catatan:",
     "Hide details" : "Sembunyikan detail",
     "Show details" : "Tampilkan detail",
     "Disable" : "Nonaktifkan",
     "Enable" : "Aktifkan",
     "Choose" : "Pilih",
+    "The file must be a PNG or JPG" : "File harus berupa PNG atau JPG",
     "Restricted" : "Terbatas",
     "Personal" : "Pribadi",
     "_%n hour_::_%n hours_" : ["%n jam"],
+    "_%n day_::_%n days_" : ["%n hari"],
+    "_%n week_::_%n weeks_" : ["%n minggu"],
     "Password protection" : "Password protection",
+    "Set a password" : "Tetapkan kata sandi",
+    "Invalid language" : "Bahasa tidak valid",
     "Edit" : "Sunting",
+    "More information" : "Informasi lebih lanjut",
     "Delete" : "Hapus",
     "Notifications" : "Pemberitahuan",
+    "In {conversation}" : "Di {conversation}",
     "Join" : "Gabung",
     "Create conversation" : "Buat percakapan",
+    "Enter your name" : "Masukkan nama Anda",
     "Log in" : "Masuk",
+    "Browse" : "Telusuri",
     "Mark as read" : "tandai sudah dibaca",
     "Mark as unread" : "Tandai belum dibaca",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
     "Home" : "Beranda",
+    "Unread" : "Belum dibaca",
     "Unread messages" : "Pesan belum dibaca",
+    "Clear filters" : "Hapus filter",
+    "Threads" : "Utas",
     "Clear filter" : "Bersihkan filter",
     "Users" : "Pengguna",
     "Groups" : "Grup",
     "Teams" : "Tim",
     "No search results" : "Tidak ada hasil pencarian",
+    "Select a device" : "Pilih perangkat",
     "Devices" : "Perangkat",
     "Invalid path selected" : "Jalur terpilih invalid",
     "Blur" : "Kabur",
     "Upload" : "Unggah",
     "Files" : "Berkas",
+    "7 days" : "7 hari",
     "Reply" : "Balas",
     "More actions" : "Tindakan lainnya",
+    "Set reminder" : "Tetapkan pengingat",
+    "Edit message" : "Edit pesan",
+    "Copy message" : "Salin pesan",
+    "Download file" : "Unduh berkas",
     "Translate" : "Terjemahkan",
+    "Set custom reminder" : "Tetapkan pengingat kustom",
+    "React with {emoji}" : "Bereaksi dengan {emoji}",
     "Dismiss" : "Batal",
+    "The message could not be translated" : "Pesan tidak dapat diterjemahkan",
+    "Translation copied to clipboard" : "Terjemahan disalin ke papan klip",
+    "Translation could not be copied" : "Terjemahan tidak dapat disalin",
+    "Translate message" : "Terjemahkan pesan",
+    "Source language to translate from" : "Bahasa sumber untuk diterjemahkan dari",
+    "Translate from" : "Terjemahkan dari",
+    "Target language to translate into" : "Bahasa target untuk diterjemahkan ke",
+    "Translate to" : "Terjemahkan ke",
+    "Translating" : "Menerjemahkan",
+    "Copy translated text" : "Salin teks terjemahan",
+    "Send now" : "Kirim sekarang",
+    "Message sent" : "Pesan terkirim",
     "Contact" : "Kontak",
+    "{stack} in {board}" : "{stack} di {board}",
+    "Remove {fileName}" : "Hapus {fileName}",
+    "_%n reply_::_%n replies_" : ["%n balasan"],
+    "Poll" : "Polling",
+    "No messages" : "Tidak ada pesan",
+    "Unpin" : "Lepas sematan",
     "Add participants" : "Tambahkan peserta",
     "Allow guests to join via link" : "Izinkan tamu untuk bergabung melalui tautan",
+    "File to share" : "Berkas untuk dibagikan",
+    "Send later" : "Kirim nanti",
+    "Cancel editing" : "Batalkan pengeditan",
+    "Share from Files" : "Bagikan dari Berkas",
+    "Upload from device" : "Unggah dari perangkat",
+    "Smart picker" : "Pemilih cerdas",
+    "End recording and send" : "Akhiri rekaman dan kirim",
+    "Dismiss recording" : "Batalkan rekaman",
+    "Error while recording audio" : "Kesalahan saat merekam audio",
     "New file" : "File baru",
     "Blank" : "Kosong",
     "Send" : "Kirim",
+    "Question" : "Pertanyaan",
     "Settings" : "Setelan",
     "guest" : "pengunjung",
+    "Remove participant" : "Hapus peserta",
     "Remove" : "Hapus",
     "Add users or groups" : "Add users or groups",
+    "Add users" : "Tambahkan pengguna",
     "Integrations" : "Integrasi",
     "Searching …" : "Mencari …",
     "Search or add participants" : "Cari atau tambah peserta",
     "An error occurred while adding the participants" : "Terjadi kesalahan saat menambahkan peserta",
+    "Participants" : "Peserta",
     "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
+    "Chat" : "Obrolan",
     "Details" : "Detail",
+    "No results found" : "Tidak ada hasil ditemukan",
     "Load more results" : "Muat lebih banyak hasil",
     "Projects" : "Proyek",
     "Search conversations or users" : "Cari percakapan atau pengguna",
+    "Select conversation" : "Pilih percakapan",
     "Notification settings" : "Pengaturan notifikasi",
+    "Default language" : "Bahasa bawaan",
     "Privacy" : "Privasi",
     "Attachments folder" : "Folder lampiran",
     "Search" : "Cari",
+    "Recording" : "Perekaman",
+    "React with {reaction}" : "Bereaksi dengan {reaction}",
+    "Start recording" : "Mulai merekam",
     "Keep" : "Simpan",
+    "Select a region" : "Pilih wilayah",
     "Submit" : "Kirim",
+    "Local time: {time}" : "Waktu lokal: {time}",
     "Join a conversation or start a new one!" : "Gabung dengan percakapan atau mulai yang baru!",
     "Join a conversation or start a new one" : "Gabung dengan percakapan atau mulai yang baru",
+    "Nextcloud URL" : "URL Nextcloud",
+    "Talk conversation" : "Percakapan Talk",
     "User" : "Pengguna",
     "Password" : "Kata kunci",
     "API token" : "Token API",
     "Login" : "Log masuk",
     "Nickname" : "Nama panggilan",
     "Client ID" : "ID Klien",
+    "Team ID" : "ID tim",
     "Media" : "Media",
+    "Polls" : "Polling",
     "Locations" : "Lokasi",
     "Audio" : "Audio",
     "Other" : "Lainnya",
@@ -374,6 +479,12 @@ OC.L10N.register(
     "Default" : "Bawaan",
     "Group" : "Grup",
     "Team" : "Tim",
+    "Error while sharing file" : "Kesalahan saat membagikan berkas",
+    "Later today – {timeLocale}" : "Nanti hari ini – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Besok – {timeLocale}",
+    "This weekend – {timeLocale}" : "Akhir pekan ini – {timeLocale}",
+    "Next week – {timeLocale}" : "Minggu depan – {timeLocale}",
+    "Error while parsing a PROPFIND error" : "Kesalahan saat mengurai kesalahan PROPFIND",
     "Please reload the page." : "Silakan muat ulang halaman.",
     "Do not disturb" : "Jangan diganggu",
     "Away" : "Jauh",
@@ -386,6 +497,11 @@ OC.L10N.register(
     "Notes" : "Catatan",
     "Reports" : "Laporan",
     "Call summary - {title}" : "Ringkasan panggilan - {judul}",
+    "Talk settings" : "Pengaturan Talk",
+    "Set reminder for later today" : "Atur pengingat untuk nanti hari ini",
+    "Set reminder for tomorrow" : "Atur pengingat untuk besok",
+    "Set reminder for this weekend" : "Atur pengingat untuk akhir pekan ini",
+    "Set reminder for next week" : "Atur pengingat untuk minggu depan",
     "Today" : "Hari ini",
     "Yesterday" : "Kemarin",
     "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
