@@ -917,13 +917,13 @@ OC.L10N.register(
     "Phone numbers" : "Numèros de telefòn",
     "Display name: {name}" : "Nom d’afichatge : {name}",
     "Save name" : "Enregistrar lo nom",
-    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
-    "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
-    "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
-    "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
     "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
     "Notification settings" : "Paramètres de notificacions",
+    "Default language" : "Lenga per defaut",
+    "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
+    "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
+    "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
     "Privacy" : "Confidencialitat",
     "Attachments folder" : "Dossièr de pèças-juntas",
     "Toggle full screen" : "Alternar ecran complèt",
@@ -972,7 +972,6 @@ OC.L10N.register(
     "Select a region" : "Seleccionatz una region",
     "Submit" : "Transmetre",
     "Search …" : "Recercar...",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Messatge sens mencion",
     "Mention myself" : "Me mencionar",
     "The conversation does not exist" : "La conversacion existís pas",
@@ -1039,6 +1038,7 @@ OC.L10N.register(
     "Default" : "Defaut",
     "Group" : "Grop",
     "You: {lastMessage}" : "Vos : {lastMessage}",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Leave this page" : "Quitar aquesta pagina",
     "Join here" : "Rejónher aquí",
     "Post to a conversation" : "Publicar dins una conversacion",
@@ -1100,6 +1100,7 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
     "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
+    "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Sounds setting saved" : "Paramètres de son enregistrats",
     "Choose devices" : "Causir periferics",
     "Browse …" : "Percórrer...",
@@ -1112,9 +1113,6 @@ OC.L10N.register(
     "Blur background" : "Rèireplan trebol",
     "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
-    "Establishing signaling connection is taking longer than expected …" : "L’establiment de la connexion de senhalizacion pren mai de temps que previst…",
-    "Failed to establish signaling connection. Retrying …" : "Fracàs de l’establiment de la connexion de senhalizacion. Novèl ensag…",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Fracàs de l’establiment de la connexion de senhalizacion. Quicòm pòt èsser maridament configurat costat servidor."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran."
 },
 "nplurals=2; plural=(n > 1);");
