@@ -494,6 +494,7 @@ OC.L10N.register(
     "Assign" : "Atribuie",
     "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
     "Now" : "Acum",
+    "Meeting" : "Videoconferință",
     "From" : "De la",
     "To" : "Către",
     "Calendar" : "Calendar",
@@ -511,6 +512,7 @@ OC.L10N.register(
     "Speaker view" : "Vizualizare vorbitor",
     "Grid view" : "Afișare în grilă",
     "This conversation is read-only" : "Această conversație este read-only",
+    "Reload" : "Reîncarcă",
     "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
     "A participant raised their hand." : "Un participant a ridicat mâna.",
     "Connecting …" : "Se conectează ...",
@@ -573,7 +575,6 @@ OC.L10N.register(
     "Restricted" : "Restricționat",
     "Advanced permissions" : "Permisiuni avansate",
     "Edit permissions" : "Editare permisiuni",
-    "Meeting" : "Videoconferință",
     "Conversation settings" : "Configurația conversației",
     "Basic Info" : "Informații de bază",
     "Personal" : "Personal",
@@ -648,6 +649,7 @@ OC.L10N.register(
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
     "Files" : "Fișiere",
+    "24 hours" : "24 de ore",
     "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
     "Reply" : "Răspunde",
     "More actions" : "Mai multe acțiuni",
@@ -656,6 +658,7 @@ OC.L10N.register(
     "Translate" : "Tradu",
     "Set custom reminder" : "Setează memento particular",
     "Dismiss" : "Elimină",
+    "Send now" : "Trimite acum",
     "Message sent" : "Mesajul a fost transmis",
     "Contact" : "Contact",
     "{stack} in {board}" : "{stack} în {board}",
@@ -668,6 +671,7 @@ OC.L10N.register(
     "Enter password" : "Introduceți parola",
     "Joining conversation …" : "Alăturare la conversație ...",
     "File to share" : "Fișier de partajat",
+    "Send later" : "Trimite mai târziu",
     "Cancel editing" : "Anulează editarea",
     "Share from Files" : "Partajează din Fișiere",
     "Upload from device" : "Încarcă din dispozitiv",
@@ -729,16 +733,14 @@ OC.L10N.register(
     "Phone numbers" : "Numere de telefon",
     "Display name: {name}" : "Numele afișat: {name}",
     "Save name" : "Salvează numele",
-    "Select location for attachments" : "Selectați locația atașamentelor",
-    "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
-    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
-    "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
-    "Error while setting typing status privacy" : "Eroare la setarea confidențialității tastării",
-    "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
     "Play sounds when participants join or leave a call" : "Avertizează sonor când cineva se alătură sau părăsește o videoconferință",
     "Notification settings" : "Setări notificări",
+    "Default language" : "Limba implicită",
+    "Select location for attachments" : "Selectați locația atașamentelor",
+    "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
+    "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
+    "Error while setting typing status privacy" : "Eroare la setarea confidențialității tastării",
     "Privacy" : "Confidențialitate",
     "Attachments folder" : "Dosarul pentru atașamente",
     "Toggle full screen" : "Comută în ecran complet",
@@ -879,6 +881,9 @@ OC.L10N.register(
     "Yesterday" : "Ieri",
     "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
     "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
+    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
+    "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
+    "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Choose devices" : "Selectați dispozitivele",
     "Browse …" : "Navigare ...",
     "Appearance" : "Aspect",
