@@ -876,13 +876,13 @@ OC.L10N.register(
     "Link to a conversation" : "Collega a una resonada",
     "Search conversations or users" : "Chirca resonadas o utentes",
     "Select conversation" : "Seletziona resonada",
-    "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
-    "Error while setting attachment folder" : "Errore in sa cunfiguratzione de sa cartella de is alligongiados",
-    "Error while setting read status privacy" : "Errore in sa cunfiguratzione de sa riservadesa de s'istadu de letura",
-    "Failed to save sounds setting" : "Non at fatu a sarvare sa cunfiguratzione de is sonos",
     "Error while saving sounds setting" : "Errore sarvende sa cunfiguratzione de is sonos",
     "Play sounds when participants join or leave a call" : "Ativa is sonos cando is partetzipantes intrant o lassant una mutida",
     "Notification settings" : "Cunfiguratzione de notìficas",
+    "Default language" : "Limba predefinida",
+    "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
+    "Error while setting attachment folder" : "Errore in sa cunfiguratzione de sa cartella de is alligongiados",
+    "Error while setting read status privacy" : "Errore in sa cunfiguratzione de sa riservadesa de s'istadu de letura",
     "Privacy" : "Riservadesa",
     "Attachments folder" : "Cartella de alligongiados",
     "Search" : "Chirca",
@@ -922,7 +922,6 @@ OC.L10N.register(
     "Keep" : "Mantene",
     "Select a region" : "Seletziona una regione",
     "Submit" : "Imbia",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Messàgiu chena mentovu",
     "Mention myself" : "Mentova a mie etotu",
     "Join a different conversation or start a new one." : "Aderi a una resonada diferente o cumintza·nde una noa.",
@@ -982,6 +981,7 @@ OC.L10N.register(
     "Default" : "Predefinidu",
     "Group" : "Grupu",
     "You: {lastMessage}" : "Tue: {lastMessage}",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
     "Leave this page" : "Lassa custa pàgina",
     "Join here" : "Intra inoghe",
@@ -1043,6 +1043,7 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["%n dies a oe","%n dies a oe"],
     "Choose the folder in which attachments should be saved." : "Sèbera in cale cartella depent èssere sarvados is alligongiados.",
     "Your privacy setting has been saved" : "Sa cunfiguratzione de riservadesa tua est istada sarvada",
+    "Failed to save sounds setting" : "Non at fatu a sarvare sa cunfiguratzione de is sonos",
     "Sounds setting saved" : "Cunfiguratzione de is sonos sarvada",
     "Choose devices" : "Sèbera dispositivos",
     "Appearance" : "Aspetu",
@@ -1055,9 +1056,6 @@ OC.L10N.register(
     "Space bar" : "Istanca de logu",
     "Sharing your screen only works with Firefox version 52 or newer." : "Podes cumpartzire s'ischermu isceti cun Firefox versione 52 o prus noa.",
     "Screensharing extension is required to share your screen." : "Pro cumpartzire s'ischermu serbit un'estensione de Screensharing.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Imprea un'àteru navigadore comente Firefox o Chrome pro cumpartzire s'ischermu.",
-    "Establishing signaling connection is taking longer than expected …" : "Sa creatzione de sa connessione de signalatzione est istentende prus de su tempus prevìdidu ...",
-    "Failed to establish signaling connection. Retrying …" : "No at fatu a creare sa connessione de signalatzione. Torrende a proare ... ",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "No at fatu a creare sa connessione de signalatzione. B'at calicuna cosa isballiada in sa cunfiguratzione de su serbidore de signalatzione"
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Imprea un'àteru navigadore comente Firefox o Chrome pro cumpartzire s'ischermu."
 },
 "nplurals=2; plural=(n != 1);");
