@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Activity;
@@ -27,16 +12,17 @@ use OCP\Activity\ActivitySettings;
 use OCP\IL10N;
 
 class Setting extends ActivitySettings {
-	protected IL10N $l;
 
-	public function __construct(IL10N $l) {
-		$this->l = $l;
+	public function __construct(
+		protected IL10N $l,
+	) {
 	}
 
 	/**
 	 * @return string Lowercase a-z and underscore only identifier
 	 * @since 11.0.0
 	 */
+	#[\Override]
 	public function getIdentifier(): string {
 		return 'spreed';
 	}
@@ -45,6 +31,7 @@ class Setting extends ActivitySettings {
 	 * @return string A translated string
 	 * @since 11.0.0
 	 */
+	#[\Override]
 	public function getName(): string {
 		return $this->l->t('You were invited to a <strong>conversation</strong> or had a <strong>call</strong>');
 	}
@@ -52,6 +39,7 @@ class Setting extends ActivitySettings {
 	/**
 	 * {@inheritdoc}
 	 */
+	#[\Override]
 	public function getGroupIdentifier(): string {
 		return 'other';
 	}
@@ -59,25 +47,29 @@ class Setting extends ActivitySettings {
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getGroupName() {
+	#[\Override]
+	public function getGroupName(): string {
 		return $this->l->t('Other activities');
 	}
 
 	/**
 	 * {@inheritdoc}
 	 */
+	#[\Override]
 	public function getPriority(): int {
 		return 51;
 	}
 	/**
 	 * {@inheritdoc}
 	 */
+	#[\Override]
 	public function canChangeNotification(): bool {
 		return false;
 	}
 	/**
 	 * {@inheritdoc}
 	 */
+	#[\Override]
 	public function isDefaultEnabledNotification(): bool {
 		return false;
 	}
