@@ -30,10 +30,12 @@ class RoomPlugin implements ISearchPlugin {
 	/**
 	 * {@inheritdoc}
 	 */
+	#[\Override]
 	public function search($search, $limit, $offset, ISearchResult $searchResult): bool {
 		if (!is_string($search) || $search === '') {
 			return false;
 		}
+		$search = mb_strtolower($search);
 
 		$userId = $this->userSession->getUser()->getUID();
 
@@ -56,10 +58,10 @@ class RoomPlugin implements ISearchPlugin {
 				continue;
 			}
 
-			if (stripos($room->getDisplayName($userId), $search) !== false) {
+			if (mb_stripos($room->getDisplayName($userId), $search) !== false) {
 				$item = $this->roomToSearchResultItem($room, $userId);
 
-				if (strtolower($item['label']) === strtolower($search)) {
+				if (mb_strtolower($item['label']) === mb_strtolower($search)) {
 					$result['exact'][] = $item;
 				} else {
 					$result['wide'][] = $item;
