@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2021, Vitor Mattos <vitor@php.rio>
- *
- * @author Vitor Mattos <vitor@php.rio>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Command\User;
@@ -33,18 +16,15 @@ use Symfony\Component\Console\Input\InputOption;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class Remove extends Base {
-	private IUserManager $userManager;
-	private Manager $manager;
 
 	public function __construct(
-		IUserManager $userManager,
-		Manager $manager,
+		private IUserManager $userManager,
+		private Manager $manager,
 	) {
 		parent::__construct();
-		$this->userManager = $userManager;
-		$this->manager = $manager;
 	}
 
+	#[\Override]
 	protected function configure(): void {
 		$this
 			->setName('talk:user:remove')
@@ -54,11 +34,19 @@ class Remove extends Base {
 				null,
 				InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY,
 				'Remove the given users from all rooms'
-			);
+			)
+			->addOption(
+				'private-only',
+				null,
+				InputOption::VALUE_NONE,
+				'Only remove the user from private rooms, retaining membership in public and open conversations as well as one-to-ones'
+			)
+		;
 	}
 
 	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$userIds = $input->getOption('user');
+		$privateOnly = $input->getOption('private-only');
 
 		$users = [];
 		foreach ($userIds as $userId) {
@@ -71,7 +59,7 @@ class Remove extends Base {
 		}
 
 		foreach ($users as $user) {
-			$this->manager->removeUserFromAllRooms($user);
+			$this->manager->removeUserFromAllRooms($user, $privateOnly);
 		}
 
 		$output->writeln('<info>Users successfully removed from all rooms.</info>');
