@@ -44,8 +44,6 @@ class Config {
 	 */
 	public const USER_STATUS_INTEGRATION_LIMIT = 1000;
 
-	private const EXPERIMENT_CHAT_RELAY = 4;
-
 	/** @var array<string, bool> */
 	protected array $canEnableSIP = [];
 
@@ -244,6 +242,15 @@ class Config {
 		);
 	}
 
+	public function getLiveTranscriptionTargetLanguageId(?string $userId = null): string {
+		return $this->config->getUserValue(
+			$userId,
+			'spreed',
+			UserPreference::LIVE_TRANSCRIPTION_TARGET_LANGUAGE_ID,
+			''
+		);
+	}
+
 	public function isDisabledForUser(IUser $user): bool {
 		$allowedGroups = $this->getAllowedTalkGroupIds();
 		if (empty($allowedGroups)) {
@@ -535,7 +542,7 @@ class Config {
 
 		if (str_starts_with($alg, 'ES')) {
 			$privKey = openssl_pkey_new([
-				'curve_name' => 'prime256v1',
+				'curve_name' => $alg === 'ES384' ? 'secp384r1' : 'prime256v1',
 				'private_key_bits' => 2048,
 				'private_key_type' => OPENSSL_KEYTYPE_EC,
 			]);
@@ -763,6 +770,28 @@ class Config {
 		return UserPreference::CONVERSATION_LIST_STYLE_TWO_LINES;
 	}
 
+	/**
+	 * User setting for chat style
+	 *
+	 * @param ?string $userId
+	 * @return UserPreference::CHAT_STYLE_*
+	 */
+	public function getChatStyle(?string $userId): string {
+		if ($userId !== null) {
+			$userSetting = $this->config->getUserValue(
+				$userId,
+				'spreed',
+				UserPreference::CHAT_STYLE,
+				UserPreference::CHAT_STYLE_SPLIT
+			);
+
+			if (in_array($userSetting, [UserPreference::CHAT_STYLE_SPLIT, UserPreference::CHAT_STYLE_UNIFIED], true)) {
+				return $userSetting;
+			}
+		}
+		return UserPreference::CHAT_STYLE_SPLIT;
+	}
+
 	/**
 	 * User setting falling back to admin defined app config
 	 */
@@ -795,15 +824,6 @@ class Config {
 		return $this->appConfig->getAppValueBool('call_end_to_end_encryption');
 	}
 
-	public function isChatRelayEnabled(): bool {
-		$isEnabled
-			= (max(0, $this->appConfig->getAppValueInt('experiments_users'))
-				| max(0, $this->appConfig->getAppValueInt('experiments_guests'))
-			)
-			& self::EXPERIMENT_CHAT_RELAY;
-		return $isEnabled === self::EXPERIMENT_CHAT_RELAY;
-	}
-
 	public function getPlaySoundsDefaultForGuests(): bool {
 		return $this->appConfig->getAppValueBool('guests_play_sounds', true);
 	}
