@@ -18,6 +18,7 @@ use OCA\Talk\Service\BreakoutRoomService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\RoomFormatter;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\ApiRoute;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\Comments\MessageTooLongException;
@@ -26,7 +27,7 @@ use OCP\IRequest;
 /**
  * @psalm-import-type TalkRoom from ResponseDefinitions
  */
-class BreakoutRoomController extends AEnvironmentAwareController {
+class BreakoutRoomController extends AEnvironmentAwareOCSController {
 	public function __construct(
 		string $appName,
 		IRequest $request,
@@ -45,13 +46,17 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 * @psalm-param BreakoutRoom::MODE_* $mode
 	 * @param int<1, 20> $amount Number of breakout rooms - Constants {@see BreakoutRoom::MINIMUM_ROOM_AMOUNT} and {@see BreakoutRoom::MAXIMUM_ROOM_AMOUNT}
 	 * @param string $attendeeMap Mapping of the attendees to breakout rooms
-	 * @return DataResponse<Http::STATUS_OK, TalkRoom[], array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkRoom>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Breakout rooms configured successfully
 	 * 400: Configuring breakout rooms errored
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/breakout-rooms/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function configureBreakoutRooms(int $mode, int $amount, string $attendeeMap = '[]'): DataResponse {
 		try {
 			$rooms = $this->breakoutRoomService->setupBreakoutRooms($this->room, $mode, $amount, $attendeeMap);
@@ -72,6 +77,10 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/breakout-rooms/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function removeBreakoutRooms(): DataResponse {
 		$this->breakoutRoomService->removeBreakoutRooms($this->room);
 
@@ -87,7 +96,7 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 * Broadcast a chat message to all breakout rooms
 	 *
 	 * @param string $message Message to broadcast
-	 * @return DataResponse<Http::STATUS_CREATED, TalkRoom[], array{}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_CREATED, list<TalkRoom>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
 	 *
 	 * 201: Chat message broadcasted successfully
 	 * 400: Broadcasting chat message is not possible
@@ -95,6 +104,10 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/breakout-rooms/{token}/broadcast', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function broadcastChatMessage(string $message): DataResponse {
 		try {
 			$rooms = $this->breakoutRoomService->broadcastChatMessage($this->room, $this->participant, $message);
@@ -111,13 +124,17 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 * Apply an attendee map to the breakout rooms
 	 *
 	 * @param string $attendeeMap JSON encoded mapping of the attendees to breakout rooms `array<int, int>`
-	 * @return DataResponse<Http::STATUS_OK, TalkRoom[], array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkRoom>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Attendee map applied successfully
 	 * 400: Applying attendee map is not possible
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/breakout-rooms/{token}/attendees', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function applyAttendeeMap(string $attendeeMap): DataResponse {
 		try {
 			$rooms = $this->breakoutRoomService->applyAttendeeMap($this->room, $attendeeMap);
@@ -138,6 +155,10 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/breakout-rooms/{token}/request-assistance', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function requestAssistance(): DataResponse {
 		try {
 			$this->breakoutRoomService->requestAssistance($this->room);
@@ -163,6 +184,10 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInParticipant]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/breakout-rooms/{token}/request-assistance', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function resetRequestForAssistance(): DataResponse {
 		try {
 			$this->breakoutRoomService->resetRequestForAssistance($this->room);
@@ -181,13 +206,17 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	/**
 	 * Start the breakout rooms
 	 *
-	 * @return DataResponse<Http::STATUS_OK, TalkRoom[], array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkRoom>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Breakout rooms started successfully
 	 * 400: Starting breakout rooms is not possible
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/breakout-rooms/{token}/rooms', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function startBreakoutRooms(): DataResponse {
 		try {
 			$rooms = $this->breakoutRoomService->startBreakoutRooms($this->room);
@@ -202,13 +231,17 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	/**
 	 * Stop the breakout rooms
 	 *
-	 * @return DataResponse<Http::STATUS_OK, TalkRoom[], array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkRoom>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>
 	 *
 	 * 200: Breakout rooms stopped successfully
 	 * 400: Stopping breakout rooms is not possible
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/breakout-rooms/{token}/rooms', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function stopBreakoutRooms(): DataResponse {
 		try {
 			$rooms = $this->breakoutRoomService->stopBreakoutRooms($this->room);
@@ -231,6 +264,10 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/breakout-rooms/{token}/switch', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function switchBreakoutRoom(string $target): DataResponse {
 		try {
 			$room = $this->breakoutRoomService->switchBreakoutRoom($this->room, $this->participant, $target);
@@ -247,7 +284,7 @@ class BreakoutRoomController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @return TalkRoom[]
+	 * @return list<TalkRoom>
 	 */
 	protected function formatMultipleRooms(array $rooms): array {
 		$return = [];
