@@ -35,7 +35,9 @@ use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Bot;
 use OCA\Talk\Model\Message;
 use OCA\Talk\Model\Reminder;
+use OCA\Talk\Model\ScheduledMessage;
 use OCA\Talk\Model\Session;
+use OCA\Talk\Model\Thread;
 use OCA\Talk\Participant;
 use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
@@ -46,6 +48,7 @@ use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\ProxyCacheMessageService;
 use OCA\Talk\Service\ReminderService;
 use OCA\Talk\Service\RoomFormatter;
+use OCA\Talk\Service\ScheduledMessageService;
 use OCA\Talk\Service\SessionService;
 use OCA\Talk\Service\ThreadService;
 use OCA\Talk\Share\Helper\Preloader;
@@ -92,6 +95,7 @@ use Psr\Log\LoggerInterface;
  * @psalm-import-type TalkChatReminderUpcoming from ResponseDefinitions
  * @psalm-import-type TalkRichObjectParameter from ResponseDefinitions
  * @psalm-import-type TalkRoom from ResponseDefinitions
+ * @psalm-import-type TalkScheduledMessage from ResponseDefinitions
  */
 class ChatController extends AEnvironmentAwareOCSController {
 	/** @var string[] */
@@ -134,6 +138,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		protected ITaskProcessingManager $taskProcessingManager,
 		protected IAppConfig $appConfig,
 		protected LoggerInterface $logger,
+		protected ScheduledMessageService $scheduledMessageManager,
 	) {
 		parent::__construct($appName, $request);
 	}
@@ -167,9 +172,34 @@ class ChatController extends AEnvironmentAwareOCSController {
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>
+	 * @template S of Http::STATUS_*
+	 * @param S $statusCode HTTP status code
+	 * @return DataResponse<S, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>
 	 */
-	protected function parseCommentToResponse(IComment $comment, ?Message $parentMessage = null): DataResponse {
+	protected function parseCommentAndParentToResponse(?IComment $comment, ?IComment $parentComment = null, int $statusCode = Http::STATUS_CREATED): DataResponse {
+		if ($comment === null) {
+			$headers = [];
+			if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
+				$headers = ['X-Chat-Last-Common-Read' => (string)$this->chatManager->getLastCommonReadMessage($this->room)];
+			}
+			return new DataResponse(null, $statusCode, $headers);
+		}
+
+		$parsedParentMessage = null;
+		if ($parentComment !== null) {
+			$parsedParentMessage = $this->messageParser->createMessage($this->room, $this->participant, $parentComment, $this->l);
+			$this->messageParser->parseMessage($parsedParentMessage);
+		}
+
+		return $this->parseCommentToResponse($comment, $parsedParentMessage, $statusCode);
+	}
+
+	/**
+	 * @template S of Http::STATUS_*
+	 * @param S $statusCode HTTP status code
+	 * @return DataResponse<S, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>
+	 */
+	protected function parseCommentToResponse(IComment $comment, ?Message $parentMessage = null, int $statusCode = Http::STATUS_CREATED): DataResponse {
 		$chatMessage = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
 		$this->messageParser->parseMessage($chatMessage);
 
@@ -178,7 +208,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 			if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
 				$headers = ['X-Chat-Last-Common-Read' => (string)$this->chatManager->getLastCommonReadMessage($this->room)];
 			}
-			return new DataResponse(null, Http::STATUS_CREATED, $headers);
+			return new DataResponse(null, $statusCode, $headers);
 		}
 
 		try {
@@ -196,7 +226,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
 			$headers = ['X-Chat-Last-Common-Read' => (string)$this->chatManager->getLastCommonReadMessage($this->room)];
 		}
-		return new DataResponse($data, Http::STATUS_CREATED, $headers);
+		return new DataResponse($data, $statusCode, $headers);
 	}
 
 	/**
@@ -272,11 +302,25 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$creationDateTime = $this->timeFactory->getDateTime('now', new \DateTimeZone('UTC'));
 
 		try {
-			$comment = $this->chatManager->sendMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, $parent, $referenceId, $silent, threadId: $threadId);
-			if ($replyTo === 0 && $threadTitle !== '') {
+			$createThread = $replyTo === 0 && $threadId === Thread::THREAD_NONE && $threadTitle !== '';
+			$threadId = $createThread ? Thread::THREAD_CREATE : $threadId;
+			$comment = $this->chatManager->sendMessage(
+				$this->room,
+				$this->participant,
+				$actorType,
+				$actorId,
+				$message,
+				$creationDateTime,
+				$parent,
+				$referenceId,
+				$silent,
+				threadId: $threadId,
+				threadTitle: $threadTitle,
+			);
+			if ($createThread) {
 				$thread = $this->threadService->createThread($this->room, (int)$comment->getId(), $threadTitle);
 				// Add to subscribed threads list
-				$this->threadService->setNotificationLevel($this->participant->getAttendee(), $thread, Participant::NOTIFY_DEFAULT);
+				$this->threadService->setNotificationLevel($this->participant->getAttendee(), $thread->getId(), Participant::NOTIFY_DEFAULT);
 
 				$this->chatManager->addSystemMessage(
 					$this->room,
@@ -304,6 +348,262 @@ class ChatController extends AEnvironmentAwareOCSController {
 		return $this->parseCommentToResponse($comment, $parentMessage);
 	}
 
+	/**
+	 * Get all scheduled messages of a given room and participant
+	 *
+	 * The author and timestamp are automatically set to the current user
+	 * and time.
+	 *
+	 * Required capability: `scheduled-messages`
+	 *
+	 * @return DataResponse<Http::STATUS_OK, list<TalkScheduledMessage>, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'actor'}, array{}>
+	 *
+	 * 200: All scheduled messages for this room and participant
+	 * 404: Actor not found
+	 */
+	#[NoAdminRequired]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequireReadWriteConversation]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/chat/{token}/schedule', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
+	public function getScheduledMessages(): DataResponse {
+		if ($this->participant->isSelfJoinedOrGuest()) {
+			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
+		}
+
+		$scheduledMessages = $this->scheduledMessageManager->getMessages(
+			$this->room,
+			$this->participant,
+			$this->getResponseFormat(),
+		);
+
+		return new DataResponse($scheduledMessages, Http::STATUS_OK);
+	}
+
+	/**
+	 * Schedules the sending of a new chat message to the given room
+	 *
+	 * The author and timestamp are automatically set to the current user
+	 * and time.
+	 *
+	 * Required capability: `scheduled-messages`
+	 *
+	 * @param string $message The message to send
+	 * @param int $sendAt When to send the scheduled message
+	 * @param int $replyTo Parent id which this scheduled message is a reply to
+	 * @psalm-param non-negative-int $replyTo
+	 * @param bool $silent If sent silent the scheduled message will not create any notifications when sent
+	 * @param string $threadTitle Only supported when not replying, when given will create a thread (requires `threads` capability)
+	 * @param int $threadId Thread id without quoting a specific message (requires `threads` capability)
+	 * @return DataResponse<Http::STATUS_CREATED, TalkScheduledMessage, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: 'message'|'reply-to'|'send-at'}, array{}>|DataResponse<Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: 'message'}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'actor'}, array{}>
+	 *
+	 * 201: Message scheduled successfully
+	 * 400: Scheduling the message is not possible
+	 * 404: Actor not found
+	 * 413: Message too long
+	 */
+	#[NoAdminRequired]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/schedule', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
+	public function scheduleMessage(
+		string $message,
+		int $sendAt,
+		int $replyTo = 0,
+		bool $silent = false,
+		string $threadTitle = '',
+		int $threadId = 0,
+	): DataResponse {
+		if ($this->participant->isSelfJoinedOrGuest()) {
+			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
+		}
+
+		if ($sendAt <= $this->timeFactory->getTime()) {
+			return new DataResponse(['error' => 'send-at'], Http::STATUS_BAD_REQUEST);
+		}
+
+		if (trim($message) === '') {
+			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
+		}
+
+		$parent = $parentMessage = null;
+		if ($replyTo !== 0) {
+			try {
+				$parent = $this->chatManager->getParentComment($this->room, (string)$replyTo);
+			} catch (NotFoundException $e) {
+				// Someone is trying to reply cross-rooms or to a non-existing message
+				return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
+			}
+
+			$parentMessage = $this->messageParser->createMessage($this->room, $this->participant, $parent, $this->l);
+			$this->messageParser->parseMessage($parentMessage);
+			if (!$parentMessage->isReplyable()) {
+				return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
+			}
+		}
+
+		if ($threadId !== 0 && !$this->threadService->validateThread($this->room->getId(), $threadId)) {
+			return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
+		}
+
+		$sendAtDateTime = $this->timeFactory->getDateTime('@' . $sendAt, new \DateTimeZone('UTC'));
+		try {
+			$createThread = $replyTo === 0 && $threadId === Thread::THREAD_NONE && $threadTitle !== '';
+			$threadId = $createThread ? Thread::THREAD_CREATE : $threadId;
+			$scheduledMessage = $this->scheduledMessageManager->scheduleMessage(
+				$this->room,
+				$this->participant,
+				$message,
+				ChatManager::VERB_MESSAGE,
+				$parent,
+				$threadId,
+				$sendAtDateTime,
+				[
+					ScheduledMessage::METADATA_THREAD_TITLE => $threadTitle,
+					ScheduledMessage::METADATA_SILENT => $silent,
+					ScheduledMessage::METADATA_THREAD_ID => $threadId,
+				]
+			);
+			$count = $this->scheduledMessageManager->getScheduledMessageCount($this->room, $this->participant);
+			$this->participantService->setHasScheduledMessages($this->participant, $count);
+		} catch (MessageTooLongException) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
+		}
+
+		$data = $this->scheduledMessageManager->parseScheduledMessage($this->getResponseFormat(), $scheduledMessage, $parentMessage);
+		return new DataResponse($data, Http::STATUS_CREATED);
+	}
+
+	/**
+	 * Update a scheduled message
+	 *
+	 * Required capability: `scheduled-messages`
+	 *
+	 * @param string $messageId The scheduled message id
+	 * @param string $message The scheduled message to send
+	 * @param int $sendAt When to send the scheduled message
+	 * @param bool $silent If sent silent the scheduled message will not create any notifications
+	 * @param string $threadTitle The thread title if scheduled message is creating a thread
+	 * @return DataResponse<Http::STATUS_ACCEPTED, TalkScheduledMessage, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: 'message'|'send-at'|'thread-title'}, array{}>|DataResponse<Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: 'message'}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'actor'|'message'}, array{}>
+	 *
+	 * 202: Message updated successfully
+	 * 400: Editing scheduled message is not possible
+	 * 404: Actor not found
+	 * 413: Message too long
+	 */
+	#[NoAdminRequired]
+	#[RequireModeratorOrNoLobby]
+	#[RequireLoggedInParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/schedule/{messageId}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
+	public function editScheduledMessage(
+		string $messageId,
+		string $message,
+		int $sendAt,
+		bool $silent = false,
+		string $threadTitle = '',
+	): DataResponse {
+		if ($this->participant->isSelfJoinedOrGuest()) {
+			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
+		}
+
+		if ($sendAt <= $this->timeFactory->getTime()) {
+			return new DataResponse(['error' => 'send-at'], Http::STATUS_BAD_REQUEST);
+		}
+
+		if (trim($message) === '') {
+			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
+		}
+
+		$sendAtDateTime = $this->timeFactory->getDateTime('@' . $sendAt, new \DateTimeZone('UTC'));
+		try {
+			$scheduledMessage = $this->scheduledMessageManager->editMessage(
+				$this->room,
+				$messageId,
+				$this->participant,
+				$message,
+				$silent,
+				$sendAtDateTime,
+				$threadTitle
+			);
+			$count = $this->scheduledMessageManager->getScheduledMessageCount($this->room, $this->participant);
+			$this->participantService->setHasScheduledMessages($this->participant, $count);
+		} catch (MessageTooLongException) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
+		} catch (\InvalidArgumentException) {
+			return new DataResponse(['error' => 'thread-title'], Http::STATUS_BAD_REQUEST);
+		} catch (DoesNotExistException) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
+		}
+
+		$parentMessage = null;
+		if ($scheduledMessage->getParentId() !== null) {
+			try {
+				$parent = $this->chatManager->getParentComment($this->room, (string)$scheduledMessage->getParentId());
+				$parentMessage = $this->messageParser->createMessage($this->room, $this->participant, $parent, $this->l);
+				$this->messageParser->parseMessage($parentMessage);
+			} catch (NotFoundException) {
+			}
+		}
+
+		$data = $this->scheduledMessageManager->parseScheduledMessage($this->getResponseFormat(), $scheduledMessage, $parentMessage);
+		return new DataResponse($data, Http::STATUS_ACCEPTED);
+	}
+
+	/**
+	 * Delete a scheduled message
+	 *
+	 * Required capability: `scheduled-messages`
+	 *
+	 * @param string $messageId The scheduled message id
+	 * @return DataResponse<Http::STATUS_OK, array{}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'actor'|'message'}, array{}>
+	 *
+	 * 200: Message deleted
+	 * 404: Message not found
+	 */
+	#[NoAdminRequired]
+	#[RequireModeratorOrNoLobby]
+	#[RequireLoggedInParticipant]
+	#[RequireReadWriteConversation]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}/schedule/{messageId}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
+	public function deleteScheduleMessage(string $messageId): DataResponse {
+		if ($this->participant->isSelfJoinedOrGuest()) {
+			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
+		}
+
+		$deleted = $this->scheduledMessageManager->deleteMessage(
+			$this->room,
+			$messageId,
+			$this->participant->getAttendee()->getActorType(),
+			$this->participant->getAttendee()->getActorId()
+		);
+
+		if ($deleted === 0) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
+		}
+
+		$count = $this->scheduledMessageManager->getScheduledMessageCount($this->room, $this->participant);
+		$this->participantService->setHasScheduledMessages($this->participant, $count);
+		return new DataResponse([], Http::STATUS_OK);
+	}
+
 	/**
 	 * Sends a rich-object to the given room
 	 *
@@ -425,7 +725,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * for the follow-up query.
 	 *
 	 * @param 0|1 $lookIntoFuture Polling for new messages (1) or getting the history of the chat (0)
-	 * @param int $limit Number of chat messages to receive (100 by default, 200 at most)
+	 * @param int<1, 200> $limit Number of chat messages to receive (100 by default, 200 at most)
 	 * @param int $lastKnownMessageId The last known message (serves as offset)
 	 * @psalm-param non-negative-int $lastKnownMessageId
 	 * @param int $lastCommonReadId The last known common read message
@@ -440,10 +740,11 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * @param 0|1 $markNotificationsAsRead Set to 0 when notifications should not be marked as read (default 1)
 	 * @param int $threadId Limit the chat message list to a given thread
 	 * @psalm-param non-negative-int $threadId
-	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'thread'}, array{}>
 	 *
 	 * 200: Messages returned
 	 * 304: No messages
+	 * 404: Thread not found
 	 */
 	#[FederationSupported]
 	#[PublicPage]
@@ -466,7 +767,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		int $markNotificationsAsRead = 1,
 		int $threadId = 0,
 	): DataResponse {
-		$limit = min(200, $limit);
+		$limit = min(200, max(1, $limit));
 		$timeout = min(30, $timeout);
 
 		if ($this->room->isFederatedConversation()) {
@@ -488,6 +789,12 @@ class ChatController extends AEnvironmentAwareOCSController {
 			);
 		}
 
+		if ($threadId !== 0) {
+			if (!$this->threadService->validateThread($this->room->getId(), $threadId)) {
+				return new DataResponse(['error' => 'thread'], Http::STATUS_NOT_FOUND);
+			}
+		}
+
 		$session = $this->participant->getSession();
 		if ($noStatusUpdate === 0 && $session instanceof Session) {
 			// The mobile apps dont do internal signaling unless in a call
@@ -813,13 +1120,14 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 *
 	 * @param int $messageId The focused message which should be in the "middle" of the returned context
 	 * @psalm-param non-negative-int $messageId
-	 * @param int<1, 100> $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
+	 * @param int<0, 100> $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
 	 * @param int $threadId Limit the chat message list to a given thread
 	 * @psalm-param non-negative-int $threadId
-	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'thread'}, array{}>
 	 *
 	 * 200: Message context returned
 	 * 304: No messages
+	 * 404: Thread not found
 	 */
 	#[FederationSupported]
 	#[PublicPage]
@@ -836,7 +1144,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		int $limit = 50,
 		int $threadId = 0,
 	): DataResponse {
-		$limit = min(100, $limit);
+		$limit = min(100, max(0, $limit));
 
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
@@ -850,14 +1158,27 @@ class ChatController extends AEnvironmentAwareOCSController {
 			);
 		}
 
+		if ($threadId !== 0) {
+			if (!$this->threadService->validateThread($this->room->getId(), $threadId)) {
+				return new DataResponse(['error' => 'thread'], Http::STATUS_NOT_FOUND);
+			}
+		}
+
 		$currentUser = $this->userManager->get($this->userId);
 		if ($messageId === 0) {
 			// Guest in a fully expired chat, no history, just loading the chat from beginning for now
 			$commentsHistory = $commentsFuture = [];
 		} else {
-			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true, $threadId);
+			// Load at least 1 history entry to get the includeLastKnown
+			$historyLimit = max(1, $limit);
+			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $historyLimit, true, $threadId);
 			$commentsHistory = array_reverse($commentsHistory);
-			$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false, threadId: $threadId);
+			if ($limit === 0) {
+				// No context requested, only the known message
+				$commentsFuture = [];
+			} else {
+				$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false, threadId: $threadId);
+			}
 		}
 
 		return $this->prepareCommentsAsDataResponse(array_merge($commentsHistory, $commentsFuture));
@@ -1546,11 +1867,14 @@ class ChatController extends AEnvironmentAwareOCSController {
 	/**
 	 * Get objects that are shared in the room overview
 	 *
+	 * Federated conversations are supported with the `federated-shared-items` capability
+	 *
 	 * @param int<1, 20> $limit Maximum number of objects
 	 * @return DataResponse<Http::STATUS_OK, array<string, list<TalkChatMessage>>, array{}>
 	 *
 	 * 200: List of shared objects messages of each type returned
 	 */
+	#[FederationSupported]
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
@@ -1559,7 +1883,13 @@ class ChatController extends AEnvironmentAwareOCSController {
 		'token' => '[a-z0-9]{4,30}',
 	])]
 	public function getObjectsSharedInRoomOverview(int $limit = 7): DataResponse {
-		$limit = min(20, $limit);
+		if ($this->room->isFederatedConversation()) {
+			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
+			$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController::class);
+			return $proxy->getObjectsSharedInRoomOverview($this->room, $this->participant, $limit);
+		}
+
+		$limit = min(20, max(1, $limit));
 
 		$objectTypes = [
 			Attachment::TYPE_AUDIO,
@@ -1568,11 +1898,28 @@ class ChatController extends AEnvironmentAwareOCSController {
 			Attachment::TYPE_LOCATION,
 			Attachment::TYPE_MEDIA,
 			Attachment::TYPE_OTHER,
+			Attachment::TYPE_PINNED,
 			Attachment::TYPE_POLL,
 			Attachment::TYPE_RECORDING,
 			Attachment::TYPE_VOICE,
 		];
 
+		if ($this->participant->getAttendee()->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
+			// No file support for federated users so far
+			$objectTypes = [
+				// Attachment::TYPE_AUDIO,
+				Attachment::TYPE_DECK_CARD,
+				// Attachment::TYPE_FILE,
+				Attachment::TYPE_LOCATION,
+				// Attachment::TYPE_MEDIA,
+				// Attachment::TYPE_OTHER,
+				Attachment::TYPE_PINNED,
+				Attachment::TYPE_POLL,
+				// Attachment::TYPE_RECORDING,
+				// Attachment::TYPE_VOICE,
+			];
+		}
+
 		$messageIdsByType = [];
 		// Get all attachments
 		foreach ($objectTypes as $objectType) {
@@ -1592,6 +1939,11 @@ class ChatController extends AEnvironmentAwareOCSController {
 					$messagesByType[$objectType][] = $messages[$messageId];
 				}
 			}
+
+			if ($objectType === Attachment::TYPE_PINNED) {
+				// Enforce sort order of pinned messages again after loading them from the comments table instead of attachments
+				uasort($messagesByType[$objectType], static fn (array $m1, array $m2): int => ($m2['metaData']['pinnedAt'] ?? 0) <=> ($m1['metaData']['pinnedAt'] ?? 0));
+			}
 		}
 
 		return new DataResponse($messagesByType, Http::STATUS_OK);
@@ -1600,6 +1952,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 	/**
 	 * Get objects that are shared in the room
 	 *
+	 * Federated conversations are supported with the `federated-shared-items` capability
+	 *
 	 * @param string $objectType Type of the objects
 	 * @param int $lastKnownMessageId ID of the last known message
 	 * @psalm-param non-negative-int $lastKnownMessageId
@@ -1608,6 +1962,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 *
 	 * 200: List of shared objects messages returned
 	 */
+	#[FederationSupported]
 	#[PublicPage]
 	#[RequireModeratorOrNoLobby]
 	#[RequireParticipant]
@@ -1616,13 +1971,38 @@ class ChatController extends AEnvironmentAwareOCSController {
 		'token' => '[a-z0-9]{4,30}',
 	])]
 	public function getObjectsSharedInRoom(string $objectType, int $lastKnownMessageId = 0, int $limit = 100): DataResponse {
+		if ($this->room->isFederatedConversation()) {
+			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
+			$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController::class);
+			return $proxy->getObjectsSharedInRoom($this->room, $this->participant, $objectType, $lastKnownMessageId, $limit);
+		}
+
+		$isFileType = [
+			Attachment::TYPE_AUDIO,
+			Attachment::TYPE_FILE,
+			Attachment::TYPE_MEDIA,
+			Attachment::TYPE_OTHER,
+			Attachment::TYPE_RECORDING,
+			Attachment::TYPE_VOICE,
+		];
+
+		if (in_array($objectType, $isFileType, true)
+			&& $this->participant->getAttendee()->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
+			// No file support for federated users so far
+			return new DataResponse([], Http::STATUS_OK, []);
+		}
+
 		$offset = max(0, $lastKnownMessageId);
-		$limit = min(200, $limit);
+		$limit = min(200, max(1, $limit));
 
 		$attachments = $this->attachmentService->getAttachmentsByType($this->room, $objectType, $offset, $limit);
 		$messageIds = array_map(static fn (Attachment $attachment): int => $attachment->getMessageId(), $attachments);
 
 		$messages = $this->getMessagesForRoom($messageIds);
+		if ($objectType === Attachment::TYPE_PINNED) {
+			// Enforce sort order of pinned messages again after loading them from the comments table instead of attachments
+			uasort($messages, static fn (array $m1, array $m2): int => ($m2['metaData']['pinnedAt'] ?? 0) <=> ($m1['metaData']['pinnedAt'] ?? 0));
+		}
 
 		$headers = [];
 		if (!empty($messages)) {
@@ -1633,6 +2013,125 @@ class ChatController extends AEnvironmentAwareOCSController {
 		return new DataResponse($messages, Http::STATUS_OK, $headers);
 	}
 
+	/**
+	 * Pin a message in a chat as a moderator
+	 *
+	 * Required capability: `pinned-messages`
+	 *
+	 * @param int $messageId ID of the message
+	 * @psalm-param non-negative-int $messageId
+	 * @param int $pinUntil Unix timestamp when to unpin the message
+	 * @psalm-param non-negative-int $pinUntil
+	 * @return DataResponse<Http::STATUS_OK, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND, array{error: 'message'|'until'|'status'}, array{}>
+	 *
+	 * 200: Message was pinned successfully
+	 * 400: Message could not be pinned
+	 * 404: Message was not found
+	 */
+	#[FederationSupported]
+	#[PublicPage]
+	#[RequireModeratorParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/chat/{token}/{messageId}/pin', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
+	public function pinMessage(int $messageId, int $pinUntil = 0): DataResponse {
+		if ($this->room->isFederatedConversation()) {
+			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
+			$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController::class);
+			return $proxy->pinMessage($this->room, $this->participant, $messageId, $pinUntil);
+		}
+
+		try {
+			$comment = $this->chatManager->getComment($this->room, (string)$messageId);
+		} catch (NotFoundException) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
+		}
+
+		if ($comment->getVerb() !== ChatManager::VERB_MESSAGE && $comment->getVerb() !== ChatManager::VERB_OBJECT_SHARED) {
+			// System message (since the message is not parsed, it has type "system")
+			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
+		}
+
+		if ($pinUntil !== 0 && $pinUntil < $this->timeFactory->getTime()) {
+			// System message (since the message is not parsed, it has type "system")
+			return new DataResponse(['error' => 'until'], Http::STATUS_BAD_REQUEST);
+		}
+
+		$systemMessageComment = $this->chatManager->pinMessage($this->room, $comment, $this->participant, $pinUntil);
+
+		return $this->parseCommentAndParentToResponse($systemMessageComment, $comment, Http::STATUS_OK);
+	}
+
+	/**
+	 * Unpin a message in a chat as a moderator
+	 *
+	 * Required capability: `pinned-messages`
+	 *
+	 * @param int $messageId ID of the message
+	 * @psalm-param non-negative-int $messageId
+	 * @return DataResponse<Http::STATUS_OK, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: 'status'}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'message'}, array{}>
+	 *
+	 * 200: Message is not pinned now
+	 * 400: Federation request answered with an unknown status code
+	 * 404: Message was not found
+	 */
+	#[FederationSupported]
+	#[PublicPage]
+	#[RequireModeratorParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}/{messageId}/pin', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
+	public function unpinMessage(int $messageId): DataResponse {
+		if ($this->room->isFederatedConversation()) {
+			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
+			$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController::class);
+			return $proxy->unpinMessage($this->room, $this->participant, $messageId);
+		}
+
+		try {
+			$comment = $this->chatManager->getComment($this->room, (string)$messageId);
+		} catch (NotFoundException) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
+		}
+
+		$systemMessageComment = $this->chatManager->unpinMessage($this->room, $comment, $this->participant);
+
+		return $this->parseCommentAndParentToResponse($systemMessageComment, $comment, Http::STATUS_OK);
+	}
+
+	/**
+	 * Hide a message in a chat as a user
+	 *
+	 * Required capability: `pinned-messages`
+	 *
+	 * @param int $messageId ID of the message
+	 * @psalm-param non-negative-int $messageId
+	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: string}, array{}>
+	 *
+	 * 200: Pinned message is now hidden
+	 * 404: Message was not found
+	 */
+	#[FederationSupported]
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequestHeader(name: 'x-nextcloud-federation', description: 'Set to 1 when the request is performed by another Nextcloud Server to indicate a federation request', indirect: true)]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/chat/{token}/{messageId}/pin/self', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+		'messageId' => '[0-9]+',
+	])]
+	public function hidePinnedMessage(int $messageId): DataResponse {
+		$this->participantService->hidePinnedMessage($this->participant, $messageId);
+		return new DataResponse(null, Http::STATUS_OK);
+	}
+
 	/**
 	 * @return array<string, TalkChatMessage>
 	 */
