@@ -13,16 +13,26 @@ use InvalidArgumentException;
 use OCA\Talk\Config;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Manager;
 use OCA\Talk\Middleware\Attribute\RequireLoggedInModeratorParticipant;
 use OCA\Talk\Middleware\Attribute\RequireModeratorParticipant;
 use OCA\Talk\Middleware\Attribute\RequireRoom;
+use OCA\Talk\Recording\RecordingFailedRequest;
+use OCA\Talk\Recording\RecordingRequest;
+use OCA\Talk\Recording\RecordingStartedRequest;
+use OCA\Talk\Recording\RecordingStoppedRequest;
 use OCA\Talk\Room;
 use OCA\Talk\Service\CertificateService;
+use OCA\Talk\Service\ChecksumVerificationService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\RecordingService;
 use OCA\Talk\Service\RoomService;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\MappingError;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Source\Source;
+use OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\ApiRoute;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
@@ -47,6 +57,7 @@ class RecordingController extends AEnvironmentAwareOCSController {
 		private RecordingService $recordingService,
 		private RoomService $roomService,
 		private ITimeFactory $timeFactory,
+		private ChecksumVerificationService $checksumVerificationService,
 		private LoggerInterface $logger,
 	) {
 		parent::__construct($appName, $request);
@@ -63,6 +74,10 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	 * 404: Recording server not found or not configured
 	 */
 	#[OpenAPI(scope: OpenAPI::SCOPE_ADMINISTRATION, tags: ['settings'])]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/recording/welcome/{serverId}', requirements: [
+		'apiVersion' => '(v1)',
+		'serverId' => '\d+',
+	])]
 	public function getWelcomeMessage(int $serverId): DataResponse {
 		$recordingServers = $this->talkConfig->getRecordingServers();
 		if (empty($recordingServers) || !isset($recordingServers[$serverId])) {
@@ -138,24 +153,18 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	 */
 	private function validateBackendRequest(string $data): bool {
 		$random = $this->request->getHeader('talk-recording-random');
-		if (empty($random) || strlen($random) < 32) {
-			$this->logger->debug('Missing random');
-			return false;
-		}
 		$checksum = $this->request->getHeader('talk-recording-checksum');
-		if (empty($checksum)) {
-			$this->logger->debug('Missing checksum');
+		$secret = $this->talkConfig->getRecordingSecret();
+		try {
+			return $this->checksumVerificationService->validateRequest($random, $checksum, $secret, $data);
+		} catch (UnauthorizedException) {
 			return false;
 		}
-		$hash = hash_hmac('sha256', $random . $data, $this->talkConfig->getRecordingSecret());
-		return hash_equals($hash, strtolower($checksum));
 	}
 
 	/**
 	 * Return the body of the backend request. This can be overridden in
 	 * tests.
-	 *
-	 * @return string
 	 */
 	protected function getInputStream(): string {
 		return (string)file_get_contents('php://input');
@@ -177,6 +186,9 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	#[BruteForceProtection(action: 'talkRecordingStatus')]
 	#[RequestHeader(name: 'talk-recording-random', description: 'Random seed used to generate the request checksum', indirect: true)]
 	#[RequestHeader(name: 'talk-recording-checksum', description: 'Checksum over the request body to verify authenticity from the recording backend', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/recording/backend', requirements: [
+		'apiVersion' => '(v1)',
+	])]
 	public function backend(): DataResponse {
 		$json = $this->getInputStream();
 		if (!$this->validateBackendRequest($json)) {
@@ -191,36 +203,39 @@ class RecordingController extends AEnvironmentAwareOCSController {
 			return $response;
 		}
 
-		$message = json_decode($json, true);
-		switch ($message['type'] ?? '') {
-			case 'started':
-				return $this->backendStarted($message['started']);
-			case 'stopped':
-				return $this->backendStopped($message['stopped']);
-			case 'failed':
-				return $this->backendFailed($message['failed']);
-			default:
-				return new DataResponse([
-					'type' => 'error',
-					'error' => [
-						'code' => 'unknown_type',
-						'message' => 'The given type ' . json_encode($message) . ' is not supported.',
-					],
-				], Http::STATUS_BAD_REQUEST);
+		try {
+			$request = (new MapperBuilder())
+				->mapper()
+				->map(RecordingRequest::class, Source::json($json));
+		} catch (MappingError $e) {
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
+			return new DataResponse([
+				'type' => 'error',
+				'error' => [
+					'code' => 'unknown_type',
+					'message' => 'The given request is not supported.',
+				],
+			], Http::STATUS_BAD_REQUEST);
 		}
+
+		return match ($request->type) {
+			RecordingRequest::TYPE_STARTED => $this->backendStarted($request->started),
+			RecordingRequest::TYPE_STOPPED => $this->backendStopped($request->stopped),
+			RecordingRequest::TYPE_FAILED => $this->backendFailed($request->failed),
+		};
 	}
 
 	/**
 	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 */
-	private function backendStarted(array $started): DataResponse {
-		$token = $started['token'];
-		$status = $started['status'];
-		$actor = $started['actor'];
+	private function backendStarted(RecordingStartedRequest $started): DataResponse {
+		$token = $started->token;
+		$status = $started->status;
+		$actor = $started->actor;
 
 		try {
 			$room = $this->manager->getRoomByToken($token);
-		} catch (RoomNotFoundException $e) {
+		} catch (RoomNotFoundException) {
 			$this->logger->debug('Failed to get room {token}', [
 				'token' => $token,
 				'app' => 'spreed-recording',
@@ -252,7 +267,7 @@ class RecordingController extends AEnvironmentAwareOCSController {
 
 		try {
 			$participant = $this->participantService->getParticipantByActor($room, $actor['type'], $actor['id']);
-		} catch (ParticipantNotFoundException $e) {
+		} catch (ParticipantNotFoundException) {
 			$participant = null;
 		}
 
@@ -264,12 +279,9 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	/**
 	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 */
-	private function backendStopped(array $stopped): DataResponse {
-		$token = $stopped['token'];
-		$actor = null;
-		if (array_key_exists('actor', $stopped)) {
-			$actor = $stopped['actor'];
-		}
+	private function backendStopped(RecordingStoppedRequest $stopped): DataResponse {
+		$token = $stopped->token;
+		$actor = $stopped->actor;
 
 		try {
 			$room = $this->manager->getRoomByToken($token);
@@ -305,12 +317,12 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	/**
 	 * @return DataResponse<Http::STATUS_OK, null, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{type: string, error: array{code: string, message: string}}, array{}>
 	 */
-	private function backendFailed(array $failed): DataResponse {
-		$token = $failed['token'];
+	private function backendFailed(RecordingFailedRequest $failed): DataResponse {
+		$token = $failed->token;
 
 		try {
 			$room = $this->manager->getRoomByToken($token);
-		} catch (RoomNotFoundException $e) {
+		} catch (RoomNotFoundException) {
 			$this->logger->debug('Failed to get room {token}', [
 				'token' => $token,
 				'app' => 'spreed-recording',
@@ -341,6 +353,10 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/recording/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function start(int $status): DataResponse {
 		try {
 			$this->recordingService->start($this->room, $status, $this->userId, $this->participant);
@@ -360,6 +376,10 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/recording/{token}', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function stop(): DataResponse {
 		try {
 			$this->recordingService->stop($this->room, $this->participant);
@@ -385,6 +405,10 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	#[RequireRoom]
 	#[RequestHeader(name: 'talk-recording-random', description: 'Random seed used to generate the request checksum', indirect: true)]
 	#[RequestHeader(name: 'talk-recording-checksum', description: 'Checksum over the request body to verify authenticity from the recording backend', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/recording/{token}/store', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function store(?string $owner): DataResponse {
 		$data = $this->room->getToken();
 		if (!$this->validateBackendRequest($data)) {
@@ -430,6 +454,10 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	 */
 	#[NoAdminRequired]
 	#[RequireModeratorParticipant]
+	#[ApiRoute(verb: 'DELETE', url: '/api/{apiVersion}/recording/{token}/notification', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function notificationDismiss(int $timestamp): DataResponse {
 		try {
 			$this->recordingService->notificationDismiss(
@@ -458,6 +486,10 @@ class RecordingController extends AEnvironmentAwareOCSController {
 	 */
 	#[NoAdminRequired]
 	#[RequireModeratorParticipant]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/recording/{token}/share-chat', requirements: [
+		'apiVersion' => '(v1)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function shareToChat(int $fileId, int $timestamp): DataResponse {
 		try {
 			$this->recordingService->shareToChat(
