@@ -13,6 +13,7 @@ use OCA\Talk\Events\BeforeSignalingResponseSentEvent;
 use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
@@ -21,12 +22,14 @@ use OCA\Talk\Participant;
 use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
 use OCA\Talk\Service\BanService;
+use OCA\Talk\Service\ChecksumVerificationService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\RoomService;
 use OCA\Talk\Service\SessionService;
 use OCA\Talk\Signaling\Messages;
 use OCA\Talk\TalkSession;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\ApiRoute;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\PublicPage;
@@ -36,7 +39,6 @@ use OCP\AppFramework\OCSController;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\DB\Exception;
 use OCP\EventDispatcher\IEventDispatcher;
-use OCP\Http\Client\IClientService;
 use OCP\IDBConnection;
 use OCP\IRequest;
 use OCP\IUser;
@@ -67,7 +69,7 @@ class SignalingController extends OCSController {
 		private IUserManager $userManager,
 		private IEventDispatcher $dispatcher,
 		private ITimeFactory $timeFactory,
-		private IClientService $clientService,
+		private ChecksumVerificationService $checksumVerificationService,
 		private BanService $banService,
 		private LoggerInterface $logger,
 		protected Authenticator $federationAuthenticator,
@@ -90,17 +92,13 @@ class SignalingController extends OCSController {
 	 */
 	private function validateRecordingBackendRequest(string $data): bool {
 		$random = $this->request->getHeader('talk-recording-random');
-		if (empty($random) || strlen($random) < 32) {
-			$this->logger->debug('Missing random');
-			return false;
-		}
 		$checksum = $this->request->getHeader('talk-recording-checksum');
-		if (empty($checksum)) {
-			$this->logger->debug('Missing checksum');
+		$secret = $this->talkConfig->getRecordingSecret();
+		try {
+			return $this->checksumVerificationService->validateRequest($random, $checksum, $secret, $data);
+		} catch (UnauthorizedException) {
 			return false;
 		}
-		$hash = hash_hmac('sha256', $random . $data, $this->talkConfig->getRecordingSecret());
-		return hash_equals($hash, strtolower($checksum));
 	}
 
 	/**
@@ -120,6 +118,9 @@ class SignalingController extends OCSController {
 	#[OpenAPI(tags: ['internal_signaling', 'external_signaling'])]
 	#[RequestHeader(name: 'talk-recording-random', description: 'Random seed used to generate the request checksum', indirect: true)]
 	#[RequestHeader(name: 'talk-recording-checksum', description: 'Checksum over the request body to verify authenticity from the recording backend', indirect: true)]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/signaling/settings', requirements: [
+		'apiVersion' => '(v3)',
+	])]
 	public function getSettings(string $token = ''): DataResponse {
 		$isRecordingRequest = false;
 
@@ -234,6 +235,61 @@ class SignalingController extends OCSController {
 		return new DataResponse($data);
 	}
 
+	/**
+	 * Backend API to query information required for standalone signaling
+	 * servers
+	 *
+	 * See sections "Backend validation" in
+	 * https://nextcloud-spreed-signaling.readthedocs.io/en/latest/standalone-signaling-api-v1/#backend-requests
+	 *
+	 * @return DataResponse<Http::STATUS_OK, array{type: string, error?: array{code: string, message: string}, auth?: array{version: string, userid?: string, user?: array<string, mixed>}, room?: array{version: string, roomid?: string, properties?: array<string, mixed>, permissions?: list<string>, session?: array<string, mixed>}}, array{}>
+	 *
+	 * 200: Always, sorry about that
+	 */
+	#[OpenAPI(scope: 'backend-signaling')]
+	#[PublicPage]
+	#[BruteForceProtection(action: 'talkSignalingSecret')]
+	#[RequestHeader(name: 'spreed-signaling-random', description: 'Random seed used to generate the request checksum', indirect: true)]
+	#[RequestHeader(name: 'spreed-signaling-checksum', description: 'Checksum over the request body to verify authenticity from the signaling backend', indirect: true)]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/signaling/backend', requirements: [
+		'apiVersion' => '(v3)',
+	])]
+	public function backend(): DataResponse {
+		$json = $this->getInputStream();
+		if (!$this->validateBackendRequest($json)) {
+			$response = new DataResponse([
+				'type' => 'error',
+				'error' => [
+					'code' => 'invalid_request',
+					'message' => 'The request could not be authenticated.',
+				],
+			]);
+			$response->throttle(['action' => 'talkSignalingSecret']);
+			return $response;
+		}
+
+		$message = json_decode($json, true);
+		switch ($message['type'] ?? '') {
+			case 'auth':
+				// Query authentication information about a user.
+				return $this->backendAuth($message['auth']);
+			case 'room':
+				// Query information about a room.
+				return $this->backendRoom($message['room']);
+			case 'ping':
+				// Ping sessions connected to a room.
+				return $this->backendPing($message['ping']);
+			default:
+				return new DataResponse([
+					'type' => 'error',
+					'error' => [
+						'code' => 'unknown_type',
+						'message' => 'The given type ' . json_encode($message) . ' is not supported.',
+					],
+				]);
+		}
+	}
+
 	/**
 	 * @psalm-return ?TalkSignalingFederationSettings
 	 */
@@ -283,6 +339,10 @@ class SignalingController extends OCSController {
 	 * 404: Signaling server not found
 	 */
 	#[OpenAPI(scope: OpenAPI::SCOPE_ADMINISTRATION, tags: ['settings'])]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/signaling/welcome/{serverId}', requirements: [
+		'apiVersion' => '(v3)',
+		'serverId' => '\d+',
+	])]
 	public function getWelcomeMessage(int $serverId): DataResponse {
 		try {
 			$testResult = $this->signalingManager->checkServerCompatibility($serverId);
@@ -304,6 +364,10 @@ class SignalingController extends OCSController {
 	 */
 	#[PublicPage]
 	#[OpenAPI(tags: ['internal_signaling'])]
+	#[ApiRoute(verb: 'POST', url: '/api/{apiVersion}/signaling/{token}', requirements: [
+		'apiVersion' => '(v3)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function sendMessages(string $token, string $messages): DataResponse {
 		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
 			return new DataResponse('Internal signaling disabled.', Http::STATUS_BAD_REQUEST);
@@ -385,10 +449,10 @@ class SignalingController extends OCSController {
 		$matchingMediaDescriptionIndex = -1;
 
 		for ($i = 0; $i < count($lines); $i++) {
-			if (strpos($lines[$i], 'a=sendrecv') === 0
-				|| strpos($lines[$i], 'a=sendonly') === 0
-				|| strpos($lines[$i], 'a=recvonly') === 0
-				|| strpos($lines[$i], 'a=inactive') === 0) {
+			if (str_starts_with($lines[$i], 'a=sendrecv')
+				|| str_starts_with($lines[$i], 'a=sendonly')
+				|| str_starts_with($lines[$i], 'a=recvonly')
+				|| str_starts_with($lines[$i], 'a=inactive')) {
 				$mediaDirectionIndex = $i;
 
 				if ($mediaDescriptionIndex < 0) {
@@ -398,11 +462,11 @@ class SignalingController extends OCSController {
 				if ($matchingMediaDescriptionIndex >= 0
 					&& $matchingMediaDescriptionIndex >= $mediaDescriptionIndex
 					&& $mediaDirectionIndex > $matchingMediaDescriptionIndex
-					&& (strpos($lines[$mediaDirectionIndex], 'a=sendrecv') === 0
-						|| strpos($lines[$mediaDirectionIndex], 'a=sendonly') === 0)) {
+					&& (str_starts_with($lines[$mediaDirectionIndex], 'a=sendrecv')
+						|| str_starts_with($lines[$mediaDirectionIndex], 'a=sendonly'))) {
 					return true;
 				}
-			} elseif (strpos($lines[$i], 'm=') === 0) {
+			} elseif (str_starts_with($lines[$i], 'm=')) {
 				// No media direction in previous matching media description,
 				// fallback to media direction in the session description or, if
 				// not set, default to "sendrecv".
@@ -410,14 +474,14 @@ class SignalingController extends OCSController {
 					&& $matchingMediaDescriptionIndex >= $mediaDescriptionIndex
 					&& $mediaDirectionIndex < $matchingMediaDescriptionIndex
 					&& ($sessionMediaDirectionIndex < 0
-						|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendrecv') === 0
-						|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendonly') === 0)) {
+						|| str_starts_with($lines[$sessionMediaDirectionIndex], 'a=sendrecv')
+						|| str_starts_with($lines[$sessionMediaDirectionIndex], 'a=sendonly'))) {
 					return true;
 				}
 
 				$mediaDescriptionIndex = $i;
 
-				if (strpos($lines[$i], 'm=' . $media) === 0) {
+				if (str_starts_with($lines[$i], 'm=' . $media)) {
 					$matchingMediaDescriptionIndex = $i;
 				}
 			}
@@ -430,8 +494,8 @@ class SignalingController extends OCSController {
 			&& $matchingMediaDescriptionIndex >= $mediaDescriptionIndex
 			&& $mediaDirectionIndex < $matchingMediaDescriptionIndex
 			&& ($sessionMediaDirectionIndex < 0
-				|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendrecv') === 0
-				|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendonly') === 0)) {
+				|| str_starts_with($lines[$sessionMediaDirectionIndex], 'a=sendrecv')
+				|| str_starts_with($lines[$sessionMediaDirectionIndex], 'a=sendonly'))) {
 			return true;
 		}
 
@@ -451,6 +515,10 @@ class SignalingController extends OCSController {
 	 */
 	#[PublicPage]
 	#[OpenAPI(tags: ['internal_signaling'])]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/signaling/{token}', requirements: [
+		'apiVersion' => '(v3)',
+		'token' => '[a-z0-9]{4,30}',
+	])]
 	public function pullMessages(string $token): DataResponse {
 		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
 			return new DataResponse('Internal signaling disabled.', Http::STATUS_BAD_REQUEST);
@@ -614,20 +682,14 @@ class SignalingController extends OCSController {
 	 * @return bool
 	 */
 	private function validateBackendRequest(string $data): bool {
-		if (!isset($_SERVER['HTTP_SPREED_SIGNALING_RANDOM'],
-			$_SERVER['HTTP_SPREED_SIGNALING_CHECKSUM'])) {
+		$random = $this->request->getHeader('spreed-signaling-random');
+		$checksum = $this->request->getHeader('spreed-signaling-checksum');
+		$secret = $this->talkConfig->getSignalingSecret();
+		try {
+			return $this->checksumVerificationService->validateRequest($random, $checksum, $secret, $data);
+		} catch (UnauthorizedException) {
 			return false;
 		}
-		$random = $_SERVER['HTTP_SPREED_SIGNALING_RANDOM'];
-		if (empty($random) || strlen($random) < 32) {
-			return false;
-		}
-		$checksum = $_SERVER['HTTP_SPREED_SIGNALING_CHECKSUM'];
-		if (empty($checksum)) {
-			return false;
-		}
-		$hash = hash_hmac('sha256', $random . $data, $this->talkConfig->getSignalingSecret());
-		return hash_equals($hash, strtolower($checksum));
 	}
 
 	/**
@@ -640,58 +702,6 @@ class SignalingController extends OCSController {
 		return (string)file_get_contents('php://input');
 	}
 
-	/**
-	 * Backend API to query information required for standalone signaling
-	 * servers
-	 *
-	 * See sections "Backend validation" in
-	 * https://nextcloud-spreed-signaling.readthedocs.io/en/latest/standalone-signaling-api-v1/#backend-requests
-	 *
-	 * @return DataResponse<Http::STATUS_OK, array{type: string, error?: array{code: string, message: string}, auth?: array{version: string, userid?: string, user?: array<string, mixed>}, room?: array{version: string, roomid?: string, properties?: array<string, mixed>, permissions?: list<string>, session?: array<string, mixed>}}, array{}>
-	 *
-	 * 200: Always, sorry about that
-	 */
-	#[OpenAPI(scope: 'backend-signaling')]
-	#[PublicPage]
-	#[BruteForceProtection(action: 'talkSignalingSecret')]
-	#[RequestHeader(name: 'spreed-signaling-random', description: 'Random seed used to generate the request checksum', indirect: true)]
-	#[RequestHeader(name: 'spreed-signaling-checksum', description: 'Checksum over the request body to verify authenticity from the signaling backend', indirect: true)]
-	public function backend(): DataResponse {
-		$json = $this->getInputStream();
-		if (!$this->validateBackendRequest($json)) {
-			$response = new DataResponse([
-				'type' => 'error',
-				'error' => [
-					'code' => 'invalid_request',
-					'message' => 'The request could not be authenticated.',
-				],
-			]);
-			$response->throttle(['action' => 'talkSignalingSecret']);
-			return $response;
-		}
-
-		$message = json_decode($json, true);
-		switch ($message['type'] ?? '') {
-			case 'auth':
-				// Query authentication information about a user.
-				return $this->backendAuth($message['auth']);
-			case 'room':
-				// Query information about a room.
-				return $this->backendRoom($message['room']);
-			case 'ping':
-				// Ping sessions connected to a room.
-				return $this->backendPing($message['ping']);
-			default:
-				return new DataResponse([
-					'type' => 'error',
-					'error' => [
-						'code' => 'unknown_type',
-						'message' => 'The given type ' . json_encode($message) . ' is not supported.',
-					],
-				]);
-		}
-	}
-
 	/**
 	 * @return DataResponse<Http::STATUS_OK, array{type: string, error?: array{code: string, message: string}, auth?: array{version: string, userid?: string, user?: array<string, mixed>}}, array{}>
 	 */
