@@ -14,6 +14,7 @@ use OCA\Talk\Config;
 use OCA\Talk\TInitialState;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Services\IInitialState;
+use OCP\Config\IUserConfig;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use OCP\Files\IRootFolder;
@@ -45,6 +46,7 @@ class TemplateLoader implements IEventListener {
 		IGroupManager $groupManager,
 		protected IRequest $request,
 		LoggerInterface $logger,
+		protected IUserConfig $userConfig,
 	) {
 		$this->initialState = $initialState;
 		$this->memcacheFactory = $memcacheFactory;
@@ -62,6 +64,7 @@ class TemplateLoader implements IEventListener {
 	 *
 	 * @param Event $event
 	 */
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof LoadSidebar)) {
 			return;
@@ -76,9 +79,10 @@ class TemplateLoader implements IEventListener {
 			return;
 		}
 
-		Util::addStyle(Application::APP_ID, 'icons');
+		Util::addStyle(Application::APP_ID, 'talk-icons');
 		if (!str_starts_with($this->request->getPathInfo(), '/apps/maps')) {
 			Util::addScript(Application::APP_ID, 'talk-files-sidebar');
+			Util::addStyle(Application::APP_ID, 'talk-files-sidebar');
 		}
 
 		if ($user instanceof IUser) {
