@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Listener;
@@ -38,20 +23,15 @@ use OCP\User\Events\BeforeUserLoggedOutEvent;
  * @template-implements IEventListener<Event>
  */
 class BeforeUserLoggedOutListener implements IEventListener {
-	private Manager $manager;
-	private ParticipantService $participantService;
-	private TalkSession $talkSession;
 
 	public function __construct(
-		Manager $manager,
-		ParticipantService $participantService,
-		TalkSession $talkSession,
+		private Manager $manager,
+		private ParticipantService $participantService,
+		private TalkSession $talkSession,
 	) {
-		$this->manager = $manager;
-		$this->participantService = $participantService;
-		$this->talkSession = $talkSession;
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof BeforeUserLoggedOutEvent)) {
 			// Unrelated
@@ -73,8 +53,7 @@ class BeforeUserLoggedOutListener implements IEventListener {
 					$this->participantService->changeInCall($room, $participant, Participant::FLAG_DISCONNECTED);
 				}
 				$this->participantService->leaveRoomAsSession($room, $participant);
-			} catch (RoomNotFoundException $e) {
-			} catch (ParticipantNotFoundException $e) {
+			} catch (RoomNotFoundException|ParticipantNotFoundException) {
 			}
 		}
 	}
