@@ -14,6 +14,7 @@ use OCA\Talk\AppInfo\Application;
 use OCA\Talk\Config;
 use OCA\Talk\TInitialState;
 use OCP\AppFramework\Services\IInitialState;
+use OCP\Config\IUserConfig;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use OCP\ICacheFactory;
@@ -37,6 +38,7 @@ class TemplateLoader implements IEventListener {
 		ICacheFactory $memcacheFactory,
 		Config $talkConfig,
 		IConfig $serverConfig,
+		protected IUserConfig $userConfig,
 		IGroupManager $groupManager,
 		LoggerInterface $logger,
 	) {
