@@ -8,9 +8,11 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Service;
 
+use OC\User\LazyUser;
 use OCA\Circles\CirclesManager;
 use OCA\Circles\Model\Circle;
 use OCA\Circles\Model\Member;
+use OCA\Files_Sharing\Event\UserShareAccessUpdatedEvent;
 use OCA\Talk\CachePrefix;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Config;
@@ -364,6 +366,22 @@ class ParticipantService {
 		$this->attendeeMapper->update($attendee);
 	}
 
+	public function resetHiddenPinnedId(Room $room, int $messagesId): void {
+		$query = $this->connection->getQueryBuilder();
+		$query->update('talk_attendees')
+			->set('hidden_pinned_id', $query->createNamedParameter(0))
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($room->getId())))
+			->andWhere($query->expr()->eq('hidden_pinned_id', $query->createNamedParameter($messagesId)));
+		$query->executeStatement();
+	}
+
+	public function hidePinnedMessage(Participant $participant, int $messagesId): void {
+		$attendee = $participant->getAttendee();
+		$attendee->setHiddenPinnedId($messagesId);
+		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
+		$this->attendeeMapper->update($attendee);
+	}
+
 	/**
 	 * @param RoomService $roomService
 	 * @param Room $room
@@ -660,6 +678,13 @@ class ParticipantService {
 			try {
 				$this->attendeeMapper->insert($attendee);
 
+				// Clear share access cache
+				if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
+					$user = new LazyUser($attendee->getActorId(), $this->userManager);
+					$event = new UserShareAccessUpdatedEvent($user);
+					$this->dispatcher->dispatchTyped($event);
+				}
+
 				if ($attendee->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
 					$response = $this->backendNotifier->sendRemoteShare((string)$attendee->getId(), $attendee->getAccessToken(), $attendee->getActorId(), $addedBy, 'user', $room, $this->getHighestPermissionAttendee($room));
 					if (!$response) {
@@ -1006,7 +1031,7 @@ class ParticipantService {
 		$users = json_decode($room->getName(), true);
 		$participants = $this->getParticipantUserIds($room);
 		if ($enforceUserId !== null) {
-			$missingUsers = !in_array($enforceUserId, $participants) ? [$enforceUserId] : [];
+			$missingUsers = !in_array($enforceUserId, $participants, true) ? [$enforceUserId] : [];
 		} else {
 			$missingUsers = array_diff($users, $participants);
 		}
@@ -1087,6 +1112,13 @@ class ParticipantService {
 		$this->sessionMapper->deleteByAttendeeId($participant->getAttendee()->getId());
 		$this->attendeeMapper->delete($participant->getAttendee());
 
+		if ($participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
+			// Clear share access cache
+			$user = new LazyUser($participant->getAttendee()->getActorId(), $this->userManager);
+			$event = new UserShareAccessUpdatedEvent($user);
+			$this->dispatcher->dispatchTyped($event);
+		}
+
 		$event = new AttendeeRemovedEvent($room, $participant->getAttendee(), $reason, $sessions);
 		$this->dispatcher->dispatchTyped($event);
 
@@ -1235,6 +1267,10 @@ class ParticipantService {
 
 		$this->attendeeMapper->delete($attendee);
 
+		// Clear share access cache
+		$event = new UserShareAccessUpdatedEvent($user);
+		$this->dispatcher->dispatchTyped($event);
+
 		$attendeeEvent = new AttendeeRemovedEvent($room, $attendee, $reason, $sessions);
 		$this->dispatcher->dispatchTyped($attendeeEvent);
 
@@ -2365,4 +2401,11 @@ class ParticipantService {
 		$this->cacheParticipant($room, $participant);
 		return $participant;
 	}
+
+	public function setHasScheduledMessages(Participant $participant, int $hasScheduledMessages): void {
+		$attendee = $participant->getAttendee();
+		$attendee->setHasScheduledMessages($hasScheduledMessages);
+		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
+		$this->attendeeMapper->update($attendee);
+	}
 }
