@@ -33,6 +33,7 @@ class BeforePreferenceSetEventListener implements IEventListener {
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof BeforePreferenceSetEvent)) {
 			// Unrelated
@@ -54,7 +55,7 @@ class BeforePreferenceSetEventListener implements IEventListener {
 	 * @internal Make private/protected once SettingsController route was removed
 	 */
 	public function validatePreference(string $userId, string $key, string|int|null $value): bool {
-		if ($key === 'attachment_folder') {
+		if ($key === UserPreference::ATTACHMENT_FOLDER) {
 			return $this->validateAttachmentFolder($userId, $value);
 		}
 
@@ -70,7 +71,7 @@ class BeforePreferenceSetEventListener implements IEventListener {
 			|| $key === UserPreference::READ_STATUS_PRIVACY) {
 			$valid = is_numeric($value) && ((int)$value === Participant::PRIVACY_PRIVATE || (int)$value === Participant::PRIVACY_PUBLIC);
 
-			if ($valid && $key === 'read_status_privacy') {
+			if ($valid && $key === UserPreference::READ_STATUS_PRIVACY) {
 				$this->participantService->updateReadPrivacyForActor(Attendee::ACTOR_USERS, $userId, (int)$value);
 			}
 			return $valid;
@@ -80,6 +81,16 @@ class BeforePreferenceSetEventListener implements IEventListener {
 		if ($key === UserPreference::CONVERSATIONS_LIST_STYLE) {
 			return $value === UserPreference::CONVERSATION_LIST_STYLE_TWO_LINES || $value === UserPreference::CONVERSATION_LIST_STYLE_COMPACT;
 		}
+		if ($key === UserPreference::CHAT_STYLE) {
+			return $value === UserPreference::CHAT_STYLE_SPLIT || $value === UserPreference::CHAT_STYLE_UNIFIED;
+		}
+
+		if ($key === UserPreference::LIVE_TRANSCRIPTION_TARGET_LANGUAGE_ID) {
+			// Accept any value, as it will be used for both local and federated
+			// instances and therefore the valid values might change depending
+			// on the instance.
+			return true;
+		}
 
 		return false;
 	}
