@@ -28,6 +28,7 @@ class Listener implements IEventListener {
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		match (get_class($event)) {
 			BeforeShareCreatedEvent::class => $this->overwriteShareTarget($event),
@@ -59,20 +60,16 @@ class Listener implements IEventListener {
 		}
 
 		if ($event->getParent() === RoomShareProvider::TALK_FOLDER_PLACEHOLDER) {
-			try {
-				$userId = $view->getOwner('/');
-			} catch (\Exception $e) {
-				// If we fail to get the owner of the view from the cache,
-				// e.g. because the user never logged in but a cron job runs
-				// We fall back to calculating the owner from the root of the view:
-				if (substr_count($view->getRoot(), '/') >= 2) {
-					// /37c09aa0-1b92-4cf6-8c66-86d8cac8c1d0/files
-					[, $userId, ] = explode('/', $view->getRoot(), 3);
-				} else {
-					// Something weird is going on, we can't fall back more
-					// so for now we don't overwrite the share path ¯\_(ツ)_/¯
-					return;
-				}
+			// If we fail to get the owner of the view from the cache,
+			// e.g. because the user never logged in but a cron job runs
+			// We fall back to calculating the owner from the root of the view:
+			if (substr_count($view->getRoot(), '/') >= 2) {
+				// /37c09aa0-1b92-4cf6-8c66-86d8cac8c1d0/files
+				[, $userId, ] = explode('/', $view->getRoot(), 3);
+			} else {
+				// Something weird is going on, we can't fall back more
+				// so for now we don't overwrite the share path ¯\_(ツ)_/¯
+				return;
 			}
 
 			$parent = $this->config->getAttachmentFolder($userId);
