@@ -7,6 +7,9 @@ namespace OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native;
 use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Compiler;
 use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 
+use function array_map;
+use function implode;
+
 /** @internal */
 final class ShortClosureNode extends Node
 {
