@@ -29,15 +29,15 @@ final class ReflectionPropertyDefinitionBuilder
         $type = $propertyTypeResolver->resolveTypeFor($reflection);
         $nativeType = $propertyTypeResolver->resolveNativeTypeFor($reflection);
         $hasDefaultValue = $this->hasDefaultValue($reflection, $type);
-        $defaultValue = $reflection->getDefaultValue();
+        $defaultValue = $hasDefaultValue ? $reflection->getDefaultValue() : null;
         $isPublic = $reflection->isPublic();
 
         if ($type instanceof UnresolvableType) {
             $type = $type->forProperty($signature);
         } elseif (! $type->matches($nativeType)) {
-            $type = UnresolvableType::forNonMatchingPropertyTypes($signature, $nativeType, $type);
+            $type = UnresolvableType::forNonMatchingTypes($nativeType, $type)->forProperty($signature);
         } elseif ($hasDefaultValue && ! $type->accepts($defaultValue)) {
-            $type = UnresolvableType::forInvalidPropertyDefaultValue($signature, $type, $defaultValue);
+            $type = UnresolvableType::forInvalidDefaultValue($type, $defaultValue)->forProperty($signature);
         }
 
         return new PropertyDefinition(
