@@ -4,8 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Reflection\TypeResolver;
 
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Annotations;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
+use OCA\Talk\Vendor\CuyZ\Valinor\Utility\Reflection\Annotations;
 use ReflectionProperty;
 
 /** @internal */
@@ -15,7 +15,7 @@ final class PropertyTypeResolver
 
     public function resolveTypeFor(ReflectionProperty $reflection): Type
     {
-        $docBlockType = $this->extractTypeFromDocBlock($reflection);
+        $docBlockType = Annotations::forProperty($reflection);
 
         return $this->typeResolver->resolveType($reflection->getType(), $docBlockType);
     }
@@ -24,19 +24,4 @@ final class PropertyTypeResolver
     {
         return $this->typeResolver->resolveNativeType($reflection->getType());
     }
-
-    public function extractTypeFromDocBlock(ReflectionProperty $reflection): ?string
-    {
-        $docBlock = $reflection->getDocComment();
-
-        if ($docBlock === false) {
-            return null;
-        }
-
-        return (new Annotations($docBlock))->firstOf(
-            '@phpstan-var',
-            '@psalm-var',
-            '@var',
-        )?->raw();
-    }
 }
