@@ -4,43 +4,49 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Library;
 
-use OCA\Talk\Vendor\CuyZ\Valinor\Cache\ChainCache;
+use OCA\Talk\Vendor\CuyZ\Valinor\Cache\Cache;
 use OCA\Talk\Vendor\CuyZ\Valinor\Cache\KeySanitizerCache;
 use OCA\Talk\Vendor\CuyZ\Valinor\Cache\RuntimeCache;
+use OCA\Talk\Vendor\CuyZ\Valinor\Cache\TypeFilesWatcher;
 use OCA\Talk\Vendor\CuyZ\Valinor\Cache\Warmup\RecursiveCacheWarmupService;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\FunctionsContainer;
-use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\CacheClassDefinitionRepository;
-use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\CacheFunctionDefinitionRepository;
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\CompiledClassDefinitionRepository;
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\CompiledFunctionDefinitionRepository;
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\Compiler\ClassDefinitionCompiler;
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\Compiler\FunctionDefinitionCompiler;
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\InMemoryClassDefinitionRepository;
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\InMemoryFunctionDefinitionRepository;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\ClassDefinitionRepository;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\FunctionDefinitionRepository;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Reflection\ReflectionAttributesRepository;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Reflection\ReflectionClassDefinitionRepository;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Reflection\ReflectionFunctionDefinitionRepository;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\ArgumentsMapper;
-use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\CacheObjectBuilderFactory;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\CircularDependencyDetectorObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\ConstructorObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\DateTimeObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\DateTimeZoneObjectBuilderFactory;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\InMemoryObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\ObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\ReflectionObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\SortingObjectBuilderFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory\StrictTypesObjectBuilderFactory;
-use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\ObjectBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ArrayNodeBuilder;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ConverterContainer;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\InterfaceInferringContainer;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\InterfaceNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ListNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\MixedNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\NodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\NullNodeBuilder;
-use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ObjectImplementations;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ObjectNodeBuilder;
-use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\RootNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ScalarNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ShapedArrayNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\TypeNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\UndefinedObjectNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\UnionNodeBuilder;
-use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ValueAlteringNodeBuilder;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Builder\ValueConverterNodeBuilder;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\RootNodeBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\TreeMapper;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\TypeArgumentsMapper;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\TypeTreeMapper;
@@ -48,18 +54,16 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\ArrayNormalizer;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Format;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\JsonNormalizer;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Normalizer;
-use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Transformer\CacheTransformer;
+use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Transformer\CompiledTransformer;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Transformer\Compiler\TransformerDefinitionBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Transformer\RecursiveTransformer;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Transformer\Transformer;
 use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Transformer\TransformerContainer;
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Factory\LexingTypeParserFactory;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Dumper\TypeDumper;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Factory\TypeParserFactory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\TypeParser;
-use OCA\Talk\Vendor\Psr\SimpleCache\CacheInterface;
 
 use function call_user_func;
-use function count;
 
 /** @internal */
 final class Container
@@ -76,17 +80,17 @@ final class Container
             TreeMapper::class => fn () => new TypeTreeMapper(
                 $this->get(TypeParser::class),
                 $this->get(RootNodeBuilder::class),
-                $settings,
             ),
 
             ArgumentsMapper::class => fn () => new TypeArgumentsMapper(
                 $this->get(FunctionDefinitionRepository::class),
                 $this->get(RootNodeBuilder::class),
-                $settings,
             ),
 
             RootNodeBuilder::class => fn () => new RootNodeBuilder(
                 $this->get(NodeBuilder::class),
+                $this->get(TypeDumper::class),
+                $settings,
             ),
 
             NodeBuilder::class => function () use ($settings) {
@@ -102,35 +106,33 @@ final class Container
                     new ObjectNodeBuilder(
                         $this->get(ClassDefinitionRepository::class),
                         $this->get(ObjectBuilderFactory::class),
+                        new InterfaceNodeBuilder(
+                            $this->get(InterfaceInferringContainer::class),
+                            new FunctionsContainer(
+                                $this->get(FunctionDefinitionRepository::class),
+                                $settings->customConstructors,
+                            ),
+                            $settings->exceptionFilter,
+                        ),
                         $settings->exceptionFilter,
                     ),
                 );
 
-                $builder = new InterfaceNodeBuilder(
+                return new ValueConverterNodeBuilder(
                     $builder,
-                    $this->get(ObjectImplementations::class),
+                    $this->get(ConverterContainer::class),
                     $this->get(ClassDefinitionRepository::class),
-                    new FunctionsContainer(
-                        $this->get(FunctionDefinitionRepository::class),
-                        $settings->customConstructors,
-                    ),
+                    $this->get(FunctionDefinitionRepository::class),
                     $settings->exceptionFilter,
                 );
-
-                if (count($settings->valueModifier) > 0) {
-                    $builder = new ValueAlteringNodeBuilder(
-                        $builder,
-                        new FunctionsContainer(
-                            $this->get(FunctionDefinitionRepository::class),
-                            $settings->valueModifier,
-                        ),
-                    );
-                }
-
-                return $builder;
             },
 
-            ObjectImplementations::class => fn () => new ObjectImplementations(
+            ConverterContainer::class => fn () => new ConverterContainer(
+                $this->get(FunctionDefinitionRepository::class),
+                $settings->convertersSortedByPriority(),
+            ),
+
+            InterfaceInferringContainer::class => fn () => new InterfaceInferringContainer(
                 new FunctionsContainer(
                     $this->get(FunctionDefinitionRepository::class),
                     $settings->inferredMapping,
@@ -149,22 +151,21 @@ final class Container
                 $factory = new DateTimeZoneObjectBuilderFactory($factory, $this->get(FunctionDefinitionRepository::class));
                 $factory = new DateTimeObjectBuilderFactory($factory, $settings->supportedDateFormats, $this->get(FunctionDefinitionRepository::class));
                 $factory = new SortingObjectBuilderFactory($factory);
+                $factory = new CircularDependencyDetectorObjectBuilderFactory($factory);
 
                 if (! $settings->allowPermissiveTypes) {
                     $factory = new StrictTypesObjectBuilderFactory($factory);
                 }
 
-                /** @var RuntimeCache<list<ObjectBuilder>> $cache */
-                $cache = new RuntimeCache();
-
-                return new CacheObjectBuilderFactory($factory, $cache);
+                return new InMemoryObjectBuilderFactory($factory);
             },
 
             Transformer::class => function () use ($settings) {
                 if (isset($settings->cache)) {
-                    return new CacheTransformer(
+                    return new CompiledTransformer(
                         $this->get(TransformerDefinitionBuilder::class),
-                        $this->get(CacheInterface::class),
+                        $this->get(TypeFilesWatcher::class),
+                        new RuntimeCache($this->get(Cache::class)), // @phpstan-ignore argument.type
                         $settings->transformersSortedByPriority(),
                     );
                 }
@@ -195,46 +196,70 @@ final class Container
                 $this->get(TransformerContainer::class),
             ),
 
-            ClassDefinitionRepository::class => fn () => new CacheClassDefinitionRepository(
-                new ReflectionClassDefinitionRepository(
+            ClassDefinitionRepository::class => function () use ($settings) {
+                $repository = new ReflectionClassDefinitionRepository(
                     $this->get(TypeParserFactory::class),
                     $settings->allowedAttributes(),
-                ),
-                $this->get(CacheInterface::class),
-            ),
+                );
 
-            FunctionDefinitionRepository::class => fn () => new CacheFunctionDefinitionRepository(
-                new ReflectionFunctionDefinitionRepository(
+                if (isset($settings->cache)) {
+                    $repository = new CompiledClassDefinitionRepository(
+                        $repository,
+                        $this->get(Cache::class),
+                        new ClassDefinitionCompiler(),
+                    );
+                }
+
+                return new InMemoryClassDefinitionRepository($repository);
+            },
+
+            FunctionDefinitionRepository::class => function () use ($settings) {
+                $repository = new ReflectionFunctionDefinitionRepository(
                     $this->get(TypeParserFactory::class),
                     new ReflectionAttributesRepository(
                         $this->get(ClassDefinitionRepository::class),
                         $settings->allowedAttributes(),
                     ),
-                ),
-                $this->get(CacheInterface::class),
-            ),
+                );
 
-            TypeParserFactory::class => fn () => new LexingTypeParserFactory(),
+                if (isset($settings->cache)) {
+                    $repository = new CompiledFunctionDefinitionRepository(
+                        $repository,
+                        $this->get(Cache::class),
+                        new FunctionDefinitionCompiler(),
+                    );
+                }
+
+                return new InMemoryFunctionDefinitionRepository($repository);
+            },
+
+            TypeParserFactory::class => fn () => new TypeParserFactory(),
 
             TypeParser::class => fn () => $this->get(TypeParserFactory::class)->buildDefaultTypeParser(),
 
+            TypeDumper::class => fn () => new TypeDumper(
+                $this->get(ClassDefinitionRepository::class),
+                $this->get(ObjectBuilderFactory::class),
+                $this->get(InterfaceInferringContainer::class),
+                new FunctionsContainer(
+                    $this->get(FunctionDefinitionRepository::class),
+                    $settings->customConstructors,
+                ),
+            ),
+
             RecursiveCacheWarmupService::class => fn () => new RecursiveCacheWarmupService(
                 $this->get(TypeParser::class),
-                $this->get(CacheInterface::class),
-                $this->get(ObjectImplementations::class),
+                $this->get(InterfaceInferringContainer::class),
                 $this->get(ClassDefinitionRepository::class),
                 $this->get(ObjectBuilderFactory::class),
             ),
 
-            CacheInterface::class => function () use ($settings) {
-                $cache = new RuntimeCache();
+            Cache::class => fn () => new KeySanitizerCache($settings->cache, $settings),
 
-                if (isset($settings->cache)) {
-                    $cache = new ChainCache($cache, new KeySanitizerCache($settings->cache, $settings));
-                }
-
-                return $cache;
-            },
+            TypeFilesWatcher::class => fn () => new TypeFilesWatcher(
+                $settings,
+                $this->get(ClassDefinitionRepository::class),
+            ),
         ];
     }
 
@@ -269,7 +294,7 @@ final class Container
      * @param class-string<T> $name
      * @return T
      */
-    private function get(string $name): object
+    public function get(string $name): object
     {
         return $this->services[$name] ??= call_user_func($this->factories[$name]); // @phpstan-ignore-line
     }
