@@ -9,9 +9,13 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Definition\ParameterDefinition;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Parameters;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Properties;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\PropertyDefinition;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\ShapedArrayElement;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\ShapedArrayType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\StringValueType;
 use IteratorAggregate;
 use Traversable;
 
+use function array_diff_key;
 use function array_keys;
 use function array_map;
 use function array_values;
@@ -22,16 +26,33 @@ use function count;
  *
  * @implements IteratorAggregate<Argument>
  */
-final class Arguments implements IteratorAggregate, Countable
+final readonly class Arguments implements IteratorAggregate, Countable
 {
     /** @var array<string, Argument> */
-    private array $arguments = [];
+    private array $arguments;
+
+    private ShapedArrayType $shapedArray;
 
     public function __construct(Argument ...$arguments)
     {
+        $args = [];
         foreach ($arguments as $argument) {
-            $this->arguments[$argument->name()] = $argument;
+            $args[$argument->name()] = $argument;
         }
+        $this->arguments = $args;
+        $this->shapedArray = new ShapedArrayType(
+            elements: array_map(
+                static fn (Argument $argument) => new ShapedArrayElement(
+                    key: new StringValueType($argument->name()),
+                    type: $argument->type(),
+                    optional: ! $argument->isRequired(),
+                    attributes: $argument->attributes(),
+                ),
+                $this->arguments,
+            ),
+            isUnsealed: false,
+            unsealedType: null,
+        );
     }
 
     public static function fromParameters(Parameters $parameters): self
@@ -63,6 +84,19 @@ final class Arguments implements IteratorAggregate, Countable
         return array_keys($this->arguments);
     }
 
+    public function merge(self $other): self
+    {
+        return new self(
+            ...$this->arguments,
+            ...array_diff_key($other->arguments, $this->arguments)
+        );
+    }
+
+    public function toShapedArray(): ShapedArrayType
+    {
+        return $this->shapedArray;
+    }
+
     /**
      * @return array<string, Argument>
      */
