@@ -7,10 +7,10 @@ namespace OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Factory;
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\ClassDefinition;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Argument;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Exception\PermissiveTypeNotAllowed;
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\CompositeType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\MixedType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\UndefinedObjectType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Utility\TypeHelper;
 
 /** @internal */
 final class StrictTypesObjectBuilderFactory implements ObjectBuilderFactory
@@ -34,10 +34,8 @@ final class StrictTypesObjectBuilderFactory implements ObjectBuilderFactory
 
     private function checkPresenceOfPermissiveType(Argument $argument, Type $type): void
     {
-        if ($type instanceof CompositeType) {
-            foreach ($type->traverse() as $subType) {
-                self::checkPresenceOfPermissiveType($argument, $subType);
-            }
+        foreach (TypeHelper::traverseRecursively($type) as $subType) {
+            self::checkPresenceOfPermissiveType($argument, $subType);
         }
 
         if ($type instanceof MixedType || $type instanceof UndefinedObjectType) {
