@@ -12,12 +12,11 @@ final class CannotMapToPermissiveType extends LogicException
 {
     public function __construct(Shell $shell)
     {
-        $type = $shell->type()->toString();
+        $type = $shell->type->toString();
 
         parent::__construct(
-            "Type `$type` at path `{$shell->path()}` is not allowed in strict mode. " .
+            "Type `$type` at path `{$shell->path}` is not allowed in strict mode. " .
             "In case `$type` is really needed, the `allowPermissiveTypes` setting can be used.",
-            1736935538,
         );
     }
 }
