@@ -5,16 +5,17 @@ declare(strict_types=1);
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Exception;
 
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\HasCode;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\HasParameters;
-use OCA\Talk\Vendor\CuyZ\Valinor\Utility\String\StringFormatter;
 use OCA\Talk\Vendor\CuyZ\Valinor\Utility\ValueDumper;
-use RuntimeException;
 
 /** @internal */
-final class InvalidListKey extends RuntimeException implements ErrorMessage, HasParameters
+final class InvalidListKey implements ErrorMessage, HasCode, HasParameters
 {
     private string $body = 'Invalid sequential key {key}, expected {expected}.';
 
+    private string $code = 'invalid_list_key';
+
     /** @var array<string, string> */
     private array $parameters;
 
@@ -24,8 +25,6 @@ final class InvalidListKey extends RuntimeException implements ErrorMessage, Has
             'key' => ValueDumper::dump($key),
             'expected' => (string)$expected,
         ];
-
-        parent::__construct(StringFormatter::for($this), 1654273010);
     }
 
     public function body(): string
@@ -33,6 +32,11 @@ final class InvalidListKey extends RuntimeException implements ErrorMessage, Has
         return $this->body;
     }
 
+    public function code(): string
+    {
+        return $this->code;
+    }
+
     public function parameters(): array
     {
         return $this->parameters;
