@@ -4,7 +4,5 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message;
 
-use Throwable;
-
 /** @api */
-interface ErrorMessage extends Message, Throwable {}
+interface ErrorMessage extends Message {}
