@@ -7,6 +7,8 @@ namespace OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\Formatter;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\DefaultMessage;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\NodeMessage;
 
+use function array_replace_recursive;
+
 /** @api */
 final class TranslationMessageFormatter implements MessageFormatter
 {
@@ -28,13 +30,15 @@ final class TranslationMessageFormatter implements MessageFormatter
     /**
      * Creates or overrides a single translation.
      *
-     * ```php
+     * ```
      * (TranslationMessageFormatter::default())->withTranslation(
      *     'fr',
      *     'Invalid value {source_value}.',
      *     'Valeur invalide {source_value}.',
      * );
      * ```
+     *
+     * @pure
      */
     public function withTranslation(string $locale, string $original, string $translation): self
     {
@@ -50,7 +54,7 @@ final class TranslationMessageFormatter implements MessageFormatter
      * The given array consists of messages to be translated and for each one a
      * list of locales with their associated translations.
      *
-     * ```php
+     * ```
      * $formatter = (TranslationMessageFormatter::default())->withTranslations([
      *     'Invalid value {source_value}.' => [
      *         'fr' => 'Valeur invalide {source_value}.',
@@ -64,6 +68,7 @@ final class TranslationMessageFormatter implements MessageFormatter
      * $message = $formatter->format($message);
      * ```
      *
+     * @pure
      * @param array<string, array<string, string>> $translations
      */
     public function withTranslations(array $translations): self
@@ -75,6 +80,7 @@ final class TranslationMessageFormatter implements MessageFormatter
         return $clone;
     }
 
+    /** @pure */
     public function format(NodeMessage $message): NodeMessage
     {
         $body = $this->translations[$message->body()][$message->locale()] ?? null;
