@@ -13,9 +13,6 @@ final class TransformerHasNoParameter extends LogicException
 {
     public function __construct(MethodDefinition|FunctionDefinition $method)
     {
-        parent::__construct(
-            "Transformer must have at least one parameter, none given for `$method->signature`.",
-            1695064946,
-        );
+        parent::__construct("Transformer must have at least one parameter, none given for `$method->signature`.");
     }
 }
