@@ -22,9 +22,6 @@ final class GenericClosingBracketMissing extends RuntimeException implements Inv
     {
         $signature = $className . '<' . implode(', ', array_map(fn (Type $type) => $type->toString(), $generics)) . '>';
 
-        parent::__construct(
-            "The closing bracket is missing for the generic `$signature`.",
-            1604333677
-        );
+        parent::__construct("The closing bracket is missing for the generic `$signature`.");
     }
 }
