@@ -10,11 +10,8 @@ use RuntimeException;
 /** @internal */
 final class ShapedArrayElementDuplicatedKey extends RuntimeException implements InvalidType
 {
-    public function __construct(string $key, string $signature)
+    public function __construct(string $key)
     {
-        parent::__construct(
-            "Key `$key` cannot be used several times in shaped array signature `$signature`.",
-            1631283279
-        );
+        parent::__construct("Key `$key` cannot be used several times in shaped array.");
     }
 }
