@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Exception\Scalar\NullableMissingRightType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\TokenStream;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NullType;
@@ -17,7 +18,11 @@ final class NullableToken implements TraversingToken
 
     public function traverse(TokenStream $stream): Type
     {
-        return new UnionType(NullType::get(), $stream->read());
+        if ($stream->done()) {
+            throw new NullableMissingRightType();
+        }
+
+        return UnionType::from(NullType::get(), $stream->read());
     }
 
     public function symbol(): string
