@@ -10,10 +10,15 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 /** @internal */
 final class TypeToken implements TraversingToken
 {
-    public function __construct(
-        private Type $type,
-        private string $symbol
-    ) {}
+    private Type $type;
+
+    private string $symbol;
+
+    public function __construct(Type $type)
+    {
+        $this->type = $type;
+        $this->symbol = $type->toString();
+    }
 
     public function traverse(TokenStream $stream): Type
     {
