@@ -4,7 +4,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token;
 
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Exception\RightUnionTypeMissing;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Exception\Union\RightUnionTypeMissing;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\TokenStream;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\UnionType;
@@ -21,7 +21,7 @@ final class UnionToken implements LeftTraversingToken
             throw new RightUnionTypeMissing($type);
         }
 
-        return new UnionType($type, $stream->read());
+        return UnionType::from($type, $stream->read());
     }
 
     public function symbol(): string
