@@ -4,11 +4,10 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token;
 
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Exception\UnknownSymbol;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Factory\Specifications\TypeParserSpecification;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\TokenStream;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
-use OCA\Talk\Vendor\CuyZ\Valinor\Utility\Reflection\Reflection;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\UnresolvableType;
 
 /** @internal */
 final class VacantToken implements TraversingToken
@@ -24,22 +23,14 @@ final class VacantToken implements TraversingToken
         $token = $this;
 
         foreach ($this->specifications as $specification) {
-            $new = $specification->manipulateToken($token);
-
-            if ($new !== $token) {
-                return $new->traverse($stream);
-            }
+            $token = $specification->manipulateToken($token);
         }
 
-        if (Reflection::enumExists($this->symbol)) {
-            return (new EnumNameToken($this->symbol))->traverse($stream);
+        if ($token !== $this) {
+            return $token->traverse($stream);
         }
 
-        if (Reflection::classOrInterfaceExists($this->symbol)) {
-            return (new ClassNameToken($this->symbol))->traverse($stream);
-        }
-
-        throw new UnknownSymbol($this->symbol);
+        return new UnresolvableType($this->symbol, "Cannot parse unknown symbol `$this->symbol`.");
     }
 
     public function symbol(): string
