@@ -4,14 +4,10 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser;
 
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Exception\InvalidType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 
 /** @internal */
 interface TypeParser
 {
-    /**
-     * @throws InvalidType
-     */
     public function parse(string $raw): Type;
 }
