@@ -40,16 +40,25 @@ final class PositiveIntegerType implements IntegerType
             return $other->isMatchedBy($this);
         }
 
+        if ($other instanceof ArrayKeyType) {
+            return $other->isMatchedBy($this);
+        }
+
         return $other instanceof self
             || $other instanceof NativeIntegerType
             || $other instanceof ScalarConcreteType
             || $other instanceof MixedType;
     }
 
+    public function inferGenericsFrom(Type $other, Generics $generics): Generics
+    {
+        return $generics;
+    }
+
     public function canCast(mixed $value): bool
     {
-        if (is_string($value)) {
-            $value = ltrim($value, '0');
+        if (is_string($value) && $value !== '') {
+            $value = ltrim($value, '0') ?: '0';
         }
 
         return ! is_bool($value)
@@ -66,7 +75,9 @@ final class PositiveIntegerType implements IntegerType
 
     public function errorMessage(): ErrorMessage
     {
-        return MessageBuilder::newError('Value {source_value} is not a valid positive integer.')->build();
+        return MessageBuilder::newError('Value {source_value} is not a valid positive integer.')
+            ->withCode('invalid_positive_integer')
+            ->build();
     }
 
     public function nativeType(): NativeIntegerType
