@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Attributes;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 
 /** @internal */
@@ -12,7 +13,8 @@ final class ShapedArrayElement
     public function __construct(
         private StringValueType|IntegerValueType $key,
         private Type $type,
-        private bool $optional = false
+        private bool $optional = false,
+        private ?Attributes $attributes = null,
     ) {}
 
     public function key(): StringValueType|IntegerValueType
@@ -30,6 +32,11 @@ final class ShapedArrayElement
         return $this->optional;
     }
 
+    public function attributes(): Attributes
+    {
+        return $this->attributes ?? Attributes::empty();
+    }
+
     public function toString(): string
     {
         return $this->isOptional()
