@@ -14,6 +14,7 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Utility\ValueDumper;
 use Stringable;
 
+use function assert;
 use function is_numeric;
 use function is_string;
 use function str_starts_with;
@@ -50,21 +51,12 @@ final class StringValueType implements StringType, FixedType
 
     public function matches(Type $other): bool
     {
-        if ($other instanceof UnionType) {
-            return $other->isMatchedBy($this);
-        }
+        return $other->accepts($this->value);
+    }
 
-        if ($other instanceof self) {
-            return $this->value === $other->value;
-        }
-
-        if ($other instanceof ArrayKeyType) {
-            return $other->isMatchedBy($this);
-        }
-
-        return $other instanceof StringType
-            || $other instanceof ScalarConcreteType
-            || $other instanceof MixedType;
+    public function inferGenericsFrom(Type $other, Generics $generics): Generics
+    {
+        return $generics;
     }
 
     public function canCast(mixed $value): bool
@@ -88,6 +80,7 @@ final class StringValueType implements StringType, FixedType
     public function errorMessage(): ErrorMessage
     {
         return MessageBuilder::newError('Value {source_value} does not match string value {expected_value}.')
+            ->withCode('invalid_string_value')
             ->withParameter('expected_value', ValueDumper::dump($this->value))
             ->build();
     }
